# DocuSign.eSign - the C# library for the DocuSign REST API

The DocuSign REST API provides you with a powerful, convenient, and simple Web services API for interacting with DocuSign.

This C# SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v2
- SDK version: 2.1.0
- Build package: io.swagger.codegen.languages.CSharpClientCodegen
    For more information, please visit [https://www.docusign.com/developer-center](https://www.docusign.com/developer-center)

<a name="frameworks-supported"></a>
## Frameworks supported
- .NET 4.0 or later
- Windows Phone 7.1 (Mango)

<a name="dependencies"></a>
## Dependencies
- [RestSharpSigned](https://www.nuget.org/packages/RestSharpSigned) - 105.1.0 or later
- [Json.NET](https://www.nuget.org/packages/Newtonsoft.Json/) - 8.0.3 or later

The DLLs included in the package may not be the latest version. We recommned using [NuGet] (https://docs.nuget.org/consume/installing-nuget) to obtain the latest version of the packages:
```
Install-Package RestSharp
Install-Package Newtonsoft.Json
```

NOTE: RestSharp versions greater than 105.1.0 have a bug which causes file uploads to fail. See [RestSharp#742](https://github.com/restsharp/RestSharp/issues/742)

<a name="installation"></a>
## Installation
Run the following command to generate the DLL
- [Mac/Linux] `/bin/sh build.sh`
- [Windows] `build.bat`

Then include the DLL (under the `bin` folder) in the C# project, and use the namespaces:
```csharp
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;
```

<a name="packaging"></a>
## Packaging

A `.nuspec` is included with the project. You can follow the Nuget quickstart to [create](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#create-the-package) and [publish](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#publish-the-package) packages.

This `.nuspec` uses placeholders from the `.csproj`, so build the `.csproj` directly:

```
nuget pack -Build -OutputDirectory out DocuSign.eSign.csproj
```

Then, publish to a [local feed](https://docs.microsoft.com/en-us/nuget/hosting-packages/local-feeds) or [other host](https://docs.microsoft.com/en-us/nuget/hosting-packages/overview) and consume the new package via Nuget as usual.

<a name="getting-started"></a>
## Getting Started

```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class Example
    {
        public void main()
        {
            
            var apiInstance = new AccountsApi();
            var previewBillingPlan = previewBillingPlan_example;  // string | When set to **true**, creates the account using a preview billing plan. (optional) 
            var newAccountDefinition = new NewAccountDefinition(); // NewAccountDefinition |  (optional) 

            try
            {
                // Creates new accounts.
                NewAccountSummary result = apiInstance.Create(previewBillingPlan, newAccountDefinition);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling AccountsApi.Create: " + e.Message );
            }
        }
    }
}
```

<a name="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://www.docusign.net/restapi*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountsApi* | [**Create**](docs/AccountsApi.md#create) | **POST** /v2/accounts | Creates new accounts.
*AccountsApi* | [**CreateBrand**](docs/AccountsApi.md#createbrand) | **POST** /v2/accounts/{accountId}/brands | Creates one or more brand profile files for the account.
*AccountsApi* | [**CreateCustomField**](docs/AccountsApi.md#createcustomfield) | **POST** /v2/accounts/{accountId}/custom_fields | Creates an acount custom field.
*AccountsApi* | [**CreateEMortgageTransaction**](docs/AccountsApi.md#createemortgagetransaction) | **POST** /v2/accounts/{accountId}/eMortgage/transactions | Starts a new eMortgage Transaction
*AccountsApi* | [**CreatePermissionProfile**](docs/AccountsApi.md#createpermissionprofile) | **POST** /v2/accounts/{accountId}/permission_profiles | Creates a new permission profile in the specified account.
*AccountsApi* | [**Delete**](docs/AccountsApi.md#delete) | **DELETE** /v2/accounts/{accountId} | Deletes the specified account.
*AccountsApi* | [**DeleteBrand**](docs/AccountsApi.md#deletebrand) | **DELETE** /v2/accounts/{accountId}/brands/{brandId} | Removes a brand.
*AccountsApi* | [**DeleteBrandLogoByType**](docs/AccountsApi.md#deletebrandlogobytype) | **DELETE** /v2/accounts/{accountId}/brands/{brandId}/logos/{logoType} | Delete one branding logo.
*AccountsApi* | [**DeleteBrands**](docs/AccountsApi.md#deletebrands) | **DELETE** /v2/accounts/{accountId}/brands | Deletes one or more brand profiles.
*AccountsApi* | [**DeleteCaptiveRecipient**](docs/AccountsApi.md#deletecaptiverecipient) | **DELETE** /v2/accounts/{accountId}/captive_recipients/{recipientPart} | Deletes the signature for one or more captive recipient records.
*AccountsApi* | [**DeleteCustomField**](docs/AccountsApi.md#deletecustomfield) | **DELETE** /v2/accounts/{accountId}/custom_fields/{customFieldId} | Delete an existing account custom field.
*AccountsApi* | [**DeleteENoteConfiguration**](docs/AccountsApi.md#deleteenoteconfiguration) | **DELETE** /v2/accounts/{accountId}/settings/enote_configuration | Deletes configuration information for the eNote eOriginal integration.
*AccountsApi* | [**DeletePermissionProfile**](docs/AccountsApi.md#deletepermissionprofile) | **DELETE** /v2/accounts/{accountId}/permission_profiles/{permissionProfileId} | Deletes a permissions profile within the specified account.
*AccountsApi* | [**GetAccountInformation**](docs/AccountsApi.md#getaccountinformation) | **GET** /v2/accounts/{accountId} | Retrieves the account information for the specified account.
*AccountsApi* | [**GetAccountTabSettings**](docs/AccountsApi.md#getaccounttabsettings) | **GET** /v2/accounts/{accountId}/settings/tabs | Returns tab settings list for specified account
*AccountsApi* | [**GetAllPaymentGatewayAccounts**](docs/AccountsApi.md#getallpaymentgatewayaccounts) | **GET** /v2/accounts/{accountId}/payment_gateway_accounts | Get all payment gateway account for the provided accountId
*AccountsApi* | [**GetBillingCharges**](docs/AccountsApi.md#getbillingcharges) | **GET** /v2/accounts/{accountId}/billing_charges | Gets list of recurring and usage charges for the account.
*AccountsApi* | [**GetBrand**](docs/AccountsApi.md#getbrand) | **GET** /v2/accounts/{accountId}/brands/{brandId} | Get information for a specific brand.
*AccountsApi* | [**GetBrandExportFile**](docs/AccountsApi.md#getbrandexportfile) | **GET** /v2/accounts/{accountId}/brands/{brandId}/file | Export a specific brand.
*AccountsApi* | [**GetBrandLogoByType**](docs/AccountsApi.md#getbrandlogobytype) | **GET** /v2/accounts/{accountId}/brands/{brandId}/logos/{logoType} | Obtains the specified image for a brand.
*AccountsApi* | [**GetBrandResources**](docs/AccountsApi.md#getbrandresources) | **GET** /v2/accounts/{accountId}/brands/{brandId}/resources | Returns the specified account's list of branding resources (metadata).
*AccountsApi* | [**GetBrandResourcesByContentType**](docs/AccountsApi.md#getbrandresourcesbycontenttype) | **GET** /v2/accounts/{accountId}/brands/{brandId}/resources/{resourceContentType} | Returns the specified branding resource file.
*AccountsApi* | [**GetConsumerDisclosure**](docs/AccountsApi.md#getconsumerdisclosure) | **GET** /v2/accounts/{accountId}/consumer_disclosure/{langCode} | Gets the Electronic Record and Signature Disclosure.
*AccountsApi* | [**GetConsumerDisclosureDefault**](docs/AccountsApi.md#getconsumerdisclosuredefault) | **GET** /v2/accounts/{accountId}/consumer_disclosure | Gets the Electronic Record and Signature Disclosure for the account.
*AccountsApi* | [**GetENoteConfiguration**](docs/AccountsApi.md#getenoteconfiguration) | **GET** /v2/accounts/{accountId}/settings/enote_configuration | Returns the configuration information for the eNote eOriginal integration.
*AccountsApi* | [**GetPasswordRules**](docs/AccountsApi.md#getpasswordrules) | **GET** /v2/accounts/{accountId}/settings/password_rules | Get the password rules
*AccountsApi* | [**GetPasswordRules_0**](docs/AccountsApi.md#getpasswordrules_0) | **GET** /v2/current_user/password_rules | Get membership account password rules
*AccountsApi* | [**GetPermissionProfile**](docs/AccountsApi.md#getpermissionprofile) | **GET** /v2/accounts/{accountId}/permission_profiles/{permissionProfileId} | Returns a permissions profile in the specified account.
*AccountsApi* | [**GetProvisioning**](docs/AccountsApi.md#getprovisioning) | **GET** /v2/accounts/provisioning | Retrieves the account provisioning information for the account.
*AccountsApi* | [**GetSupportedLanguages**](docs/AccountsApi.md#getsupportedlanguages) | **GET** /v2/accounts/{accountId}/supported_languages | Gets list of supported languages for recipient language setting.
*AccountsApi* | [**GetWatermark**](docs/AccountsApi.md#getwatermark) | **GET** /v2/accounts/{accountId}/watermark | Get watermark information.
*AccountsApi* | [**GetWatermarkPreview**](docs/AccountsApi.md#getwatermarkpreview) | **PUT** /v2/accounts/{accountId}/watermark/preview | Get watermark preview.
*AccountsApi* | [**ListBrands**](docs/AccountsApi.md#listbrands) | **GET** /v2/accounts/{accountId}/brands | Gets a list of brand profiles.
*AccountsApi* | [**ListCustomFields**](docs/AccountsApi.md#listcustomfields) | **GET** /v2/accounts/{accountId}/custom_fields | Gets a list of custom fields associated with the account.
*AccountsApi* | [**ListPermissions**](docs/AccountsApi.md#listpermissions) | **GET** /v2/accounts/{accountId}/permission_profiles | Gets a list of permission profiles.
*AccountsApi* | [**ListRecipientNamesByEmail**](docs/AccountsApi.md#listrecipientnamesbyemail) | **GET** /v2/accounts/{accountId}/recipient_names | Gets recipient names associated with an email address.
*AccountsApi* | [**ListSettings**](docs/AccountsApi.md#listsettings) | **GET** /v2/accounts/{accountId}/settings | Gets account settings information.
*AccountsApi* | [**ListSharedAccess**](docs/AccountsApi.md#listsharedaccess) | **GET** /v2/accounts/{accountId}/shared_access | Reserved: Gets the shared item status for one or more users.
*AccountsApi* | [**ListSignatureProviders**](docs/AccountsApi.md#listsignatureproviders) | **GET** /v2/accounts/{accountId}/signatureProviders | Returns Account available signature providers for specified account.
*AccountsApi* | [**ListUnsupportedFileTypes**](docs/AccountsApi.md#listunsupportedfiletypes) | **GET** /v2/accounts/{accountId}/unsupported_file_types | Gets a list of unsupported file types.
*AccountsApi* | [**UpdateAccountTabSettings**](docs/AccountsApi.md#updateaccounttabsettings) | **PUT** /v2/accounts/{accountId}/settings/tabs | Modifies tab settings for specified account
*AccountsApi* | [**UpdateBrand**](docs/AccountsApi.md#updatebrand) | **PUT** /v2/accounts/{accountId}/brands/{brandId} | Updates an existing brand.
*AccountsApi* | [**UpdateBrandLogoByType**](docs/AccountsApi.md#updatebrandlogobytype) | **PUT** /v2/accounts/{accountId}/brands/{brandId}/logos/{logoType} | Put one branding logo.
*AccountsApi* | [**UpdateBrandResourcesByContentType**](docs/AccountsApi.md#updatebrandresourcesbycontenttype) | **PUT** /v2/accounts/{accountId}/brands/{brandId}/resources/{resourceContentType} | Uploads a branding resource file.
*AccountsApi* | [**UpdateConsumerDisclosure**](docs/AccountsApi.md#updateconsumerdisclosure) | **PUT** /v2/accounts/{accountId}/consumer_disclosure/{langCode} | Update Consumer Disclosure.
*AccountsApi* | [**UpdateCustomField**](docs/AccountsApi.md#updatecustomfield) | **PUT** /v2/accounts/{accountId}/custom_fields/{customFieldId} | Updates an existing account custom field.
*AccountsApi* | [**UpdateENoteConfiguration**](docs/AccountsApi.md#updateenoteconfiguration) | **PUT** /v2/accounts/{accountId}/settings/enote_configuration | Updates configuration information for the eNote eOriginal integration.
*AccountsApi* | [**UpdatePasswordRules**](docs/AccountsApi.md#updatepasswordrules) | **PUT** /v2/accounts/{accountId}/settings/password_rules | Update the password rules
*AccountsApi* | [**UpdatePermissionProfile**](docs/AccountsApi.md#updatepermissionprofile) | **PUT** /v2/accounts/{accountId}/permission_profiles/{permissionProfileId} | Updates a permission profile within the specified account.
*AccountsApi* | [**UpdateSettings**](docs/AccountsApi.md#updatesettings) | **PUT** /v2/accounts/{accountId}/settings | Updates the account settings for an account.
*AccountsApi* | [**UpdateSharedAccess**](docs/AccountsApi.md#updatesharedaccess) | **PUT** /v2/accounts/{accountId}/shared_access | Reserved: Sets the shared access information for users.
*AccountsApi* | [**UpdateWatermark**](docs/AccountsApi.md#updatewatermark) | **PUT** /v2/accounts/{accountId}/watermark | Update watermark information.
*AuthenticationApi* | [**DeleteSocialLogin**](docs/AuthenticationApi.md#deletesociallogin) | **DELETE** /v2/accounts/{accountId}/users/{userId}/social | Deletes user's social account.
*AuthenticationApi* | [**GetOAuthToken**](docs/AuthenticationApi.md#getoauthtoken) | **POST** /v2/oauth2/token | Creates an authorization token.
*AuthenticationApi* | [**ListSocialLogins**](docs/AuthenticationApi.md#listsociallogins) | **GET** /v2/accounts/{accountId}/users/{userId}/social | Gets a list of a user's social accounts.
*AuthenticationApi* | [**Login**](docs/AuthenticationApi.md#login) | **GET** /v2/login_information | Gets login information for a specified user.
*AuthenticationApi* | [**RevokeOAuthToken**](docs/AuthenticationApi.md#revokeoauthtoken) | **POST** /v2/oauth2/revoke | Revokes an authorization token.
*AuthenticationApi* | [**UpdatePassword**](docs/AuthenticationApi.md#updatepassword) | **PUT** /v2/login_information/{loginPart} | Updates the password for a specified user.
*AuthenticationApi* | [**UpdateSocialLogin**](docs/AuthenticationApi.md#updatesociallogin) | **PUT** /v2/accounts/{accountId}/users/{userId}/social | Adds social account for a user.
*BillingApi* | [**GetBillingPlan**](docs/BillingApi.md#getbillingplan) | **GET** /v2/billing_plans/{billingPlanId} | Get the billing plan details.
*BillingApi* | [**GetCreditCardInfo**](docs/BillingApi.md#getcreditcardinfo) | **GET** /v2/accounts/{accountId}/billing_plan/credit_card | Get metadata for a given credit card.
*BillingApi* | [**GetInvoice**](docs/BillingApi.md#getinvoice) | **GET** /v2/accounts/{accountId}/billing_invoices/{invoiceId} | Retrieves a billing invoice.
*BillingApi* | [**GetPayment**](docs/BillingApi.md#getpayment) | **GET** /v2/accounts/{accountId}/billing_payments/{paymentId} | Gets billing payment information for a specific payment.
*BillingApi* | [**GetPlan**](docs/BillingApi.md#getplan) | **GET** /v2/accounts/{accountId}/billing_plan | Get Account Billing Plan
*BillingApi* | [**ListBillingPlans**](docs/BillingApi.md#listbillingplans) | **GET** /v2/billing_plans | Gets the list of available billing plans.
*BillingApi* | [**ListInvoices**](docs/BillingApi.md#listinvoices) | **GET** /v2/accounts/{accountId}/billing_invoices | Get a List of Billing Invoices
*BillingApi* | [**ListInvoicesPastDue**](docs/BillingApi.md#listinvoicespastdue) | **GET** /v2/accounts/{accountId}/billing_invoices_past_due | Get a list of past due invoices.
*BillingApi* | [**ListPayments**](docs/BillingApi.md#listpayments) | **GET** /v2/accounts/{accountId}/billing_payments | Gets payment information for one or more payments.
*BillingApi* | [**MakePayment**](docs/BillingApi.md#makepayment) | **POST** /v2/accounts/{accountId}/billing_payments | Posts a payment to a past due invoice.
*BillingApi* | [**PurchaseEnvelopes**](docs/BillingApi.md#purchaseenvelopes) | **PUT** /v2/accounts/{accountId}/billing_plan/purchased_envelopes | Reserverd: Purchase additional envelopes.
*BillingApi* | [**UpdatePlan**](docs/BillingApi.md#updateplan) | **PUT** /v2/accounts/{accountId}/billing_plan | Updates the account billing plan.
*BulkEnvelopesApi* | [**DeleteRecipients**](docs/BulkEnvelopesApi.md#deleterecipients) | **DELETE** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId}/bulk_recipients | Deletes the bulk recipient file from an envelope.
*BulkEnvelopesApi* | [**Get**](docs/BulkEnvelopesApi.md#get) | **GET** /v2/accounts/{accountId}/bulk_envelopes/{batchId} | Gets the status of a specified bulk send operation.
*BulkEnvelopesApi* | [**GetRecipients**](docs/BulkEnvelopesApi.md#getrecipients) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId}/bulk_recipients | Gets the bulk recipient file from an envelope.
*BulkEnvelopesApi* | [**List**](docs/BulkEnvelopesApi.md#list) | **GET** /v2/accounts/{accountId}/bulk_envelopes | Gets status information about bulk recipient batches.
*BulkEnvelopesApi* | [**UpdateRecipients**](docs/BulkEnvelopesApi.md#updaterecipients) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId}/bulk_recipients | Adds or replaces envelope bulk recipients.
*CloudStorageApi* | [**CreateProvider**](docs/CloudStorageApi.md#createprovider) | **POST** /v2/accounts/{accountId}/users/{userId}/cloud_storage | Configures the redirect URL information  for one or more cloud storage providers for the specified user.
*CloudStorageApi* | [**DeleteProvider**](docs/CloudStorageApi.md#deleteprovider) | **DELETE** /v2/accounts/{accountId}/users/{userId}/cloud_storage/{serviceId} | Deletes the user authentication information for the specified cloud storage provider.
*CloudStorageApi* | [**DeleteProviders**](docs/CloudStorageApi.md#deleteproviders) | **DELETE** /v2/accounts/{accountId}/users/{userId}/cloud_storage | Deletes the user authentication information for one or more cloud storage providers.
*CloudStorageApi* | [**GetProvider**](docs/CloudStorageApi.md#getprovider) | **GET** /v2/accounts/{accountId}/users/{userId}/cloud_storage/{serviceId} | Gets the specified Cloud Storage Provider configuration for the User.
*CloudStorageApi* | [**List**](docs/CloudStorageApi.md#list) | **GET** /v2/accounts/{accountId}/users/{userId}/cloud_storage/{serviceId}/folders/{folderId} | Gets a list of all the items from the specified cloud storage provider.
*CloudStorageApi* | [**ListFolders**](docs/CloudStorageApi.md#listfolders) | **GET** /v2/accounts/{accountId}/users/{userId}/cloud_storage/{serviceId}/folders | Retrieves a list of all the items in a specified folder from the specified cloud storage provider.
*CloudStorageApi* | [**ListProviders**](docs/CloudStorageApi.md#listproviders) | **GET** /v2/accounts/{accountId}/users/{userId}/cloud_storage | Get the Cloud Storage Provider configuration for the specified user.
*ConnectApi* | [**CreateConfiguration**](docs/ConnectApi.md#createconfiguration) | **POST** /v2/accounts/{accountId}/connect | Creates a connect configuration for the specified account.
*ConnectApi* | [**DeleteConfiguration**](docs/ConnectApi.md#deleteconfiguration) | **DELETE** /v2/accounts/{accountId}/connect/{connectId} | Deletes the specified connect configuration.
*ConnectApi* | [**DeleteEventFailureLog**](docs/ConnectApi.md#deleteeventfailurelog) | **DELETE** /v2/accounts/{accountId}/connect/failures/{failureId} | Deletes a Connect failure log entry.
*ConnectApi* | [**DeleteEventLog**](docs/ConnectApi.md#deleteeventlog) | **DELETE** /v2/accounts/{accountId}/connect/logs/{logId} | Deletes a specified Connect log entry.
*ConnectApi* | [**DeleteEventLogs**](docs/ConnectApi.md#deleteeventlogs) | **DELETE** /v2/accounts/{accountId}/connect/logs | Gets a list of Connect log entries.
*ConnectApi* | [**DeleteMobileNotifiers**](docs/ConnectApi.md#deletemobilenotifiers) | **DELETE** /v2/accounts/{accountId}/connect/mobile_notifiers | Reserved
*ConnectApi* | [**GetConfiguration**](docs/ConnectApi.md#getconfiguration) | **GET** /v2/accounts/{accountId}/connect/{connectId} | Get a Connect Configuration Information
*ConnectApi* | [**GetEventLog**](docs/ConnectApi.md#geteventlog) | **GET** /v2/accounts/{accountId}/connect/logs/{logId} | Get the specified Connect log entry.
*ConnectApi* | [**ListConfigurations**](docs/ConnectApi.md#listconfigurations) | **GET** /v2/accounts/{accountId}/connect | Get Connect Configuration Information
*ConnectApi* | [**ListEventFailureLogs**](docs/ConnectApi.md#listeventfailurelogs) | **GET** /v2/accounts/{accountId}/connect/failures | Gets the Connect failure log information.
*ConnectApi* | [**ListEventLogs**](docs/ConnectApi.md#listeventlogs) | **GET** /v2/accounts/{accountId}/connect/logs | Gets the Connect log.
*ConnectApi* | [**ListMobileNotifiers**](docs/ConnectApi.md#listmobilenotifiers) | **GET** /v2/accounts/{accountId}/connect/mobile_notifiers | Reserved
*ConnectApi* | [**ListTests**](docs/ConnectApi.md#listtests) | **GET** /v2/accounts/{accountId}/connect/{connectId}/tests | Test connect configuration.
*ConnectApi* | [**ListUsers**](docs/ConnectApi.md#listusers) | **GET** /v2/accounts/{accountId}/connect/{connectId}/users | Returns users from the configured Connect service.
*ConnectApi* | [**RetryEventForEnvelope**](docs/ConnectApi.md#retryeventforenvelope) | **PUT** /v2/accounts/{accountId}/connect/envelopes/{envelopeId}/retry_queue | Republishes Connect information for the specified envelope.
*ConnectApi* | [**RetryEventForEnvelopes**](docs/ConnectApi.md#retryeventforenvelopes) | **PUT** /v2/accounts/{accountId}/connect/envelopes/retry_queue | Republishes Connect information for multiple envelopes.
*ConnectApi* | [**UpdateConfiguration**](docs/ConnectApi.md#updateconfiguration) | **PUT** /v2/accounts/{accountId}/connect | Updates a specified Connect configuration.
*ConnectApi* | [**UpdateMobileNotifiers**](docs/ConnectApi.md#updatemobilenotifiers) | **PUT** /v2/accounts/{accountId}/connect/mobile_notifiers | Reserved
*CustomTabsApi* | [**Create**](docs/CustomTabsApi.md#create) | **POST** /v2/accounts/{accountId}/tab_definitions | Creates a custom tab.
*CustomTabsApi* | [**Delete**](docs/CustomTabsApi.md#delete) | **DELETE** /v2/accounts/{accountId}/tab_definitions/{customTabId} | Deletes custom tab information.
*CustomTabsApi* | [**Get**](docs/CustomTabsApi.md#get) | **GET** /v2/accounts/{accountId}/tab_definitions/{customTabId} | Gets custom tab information.
*CustomTabsApi* | [**List**](docs/CustomTabsApi.md#list) | **GET** /v2/accounts/{accountId}/tab_definitions | Gets a list of all account tabs.
*CustomTabsApi* | [**Update**](docs/CustomTabsApi.md#update) | **PUT** /v2/accounts/{accountId}/tab_definitions/{customTabId} | Updates custom tab information.  
*DiagnosticsApi* | [**DeleteRequestLogs**](docs/DiagnosticsApi.md#deleterequestlogs) | **DELETE** /v2/diagnostics/request_logs | Deletes the request log files.
*DiagnosticsApi* | [**GetRequestLog**](docs/DiagnosticsApi.md#getrequestlog) | **GET** /v2/diagnostics/request_logs/{requestLogId} | Gets a request logging log file.
*DiagnosticsApi* | [**GetRequestLogSettings**](docs/DiagnosticsApi.md#getrequestlogsettings) | **GET** /v2/diagnostics/settings | Gets the API request logging settings.
*DiagnosticsApi* | [**GetResources**](docs/DiagnosticsApi.md#getresources) | **GET** /v2 | Lists resources for REST version specified
*DiagnosticsApi* | [**GetService**](docs/DiagnosticsApi.md#getservice) | **GET** /service_information | Retrieves the available REST API versions.
*DiagnosticsApi* | [**ListRequestLogs**](docs/DiagnosticsApi.md#listrequestlogs) | **GET** /v2/diagnostics/request_logs | Gets the API request logging log files.
*DiagnosticsApi* | [**UpdateRequestLogSettings**](docs/DiagnosticsApi.md#updaterequestlogsettings) | **PUT** /v2/diagnostics/settings | Enables or disables API request logging for troubleshooting.
*EnvelopesApi* | [**ApplyTemplate**](docs/EnvelopesApi.md#applytemplate) | **POST** /v2/accounts/{accountId}/envelopes/{envelopeId}/templates | Adds templates to an envelope.
*EnvelopesApi* | [**ApplyTemplateToDocument**](docs/EnvelopesApi.md#applytemplatetodocument) | **POST** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents/{documentId}/templates | Adds templates to a document in an  envelope.
*EnvelopesApi* | [**CreateChunkedUpload**](docs/EnvelopesApi.md#createchunkedupload) | **POST** /v2/accounts/{accountId}/chunked_uploads | Initiate a new ChunkedUpload.
*EnvelopesApi* | [**CreateConsoleView**](docs/EnvelopesApi.md#createconsoleview) | **POST** /v2/accounts/{accountId}/views/console | Returns a URL to the authentication view UI.
*EnvelopesApi* | [**CreateCorrectView**](docs/EnvelopesApi.md#createcorrectview) | **POST** /v2/accounts/{accountId}/envelopes/{envelopeId}/views/correct | Returns a URL to the envelope correction UI.
*EnvelopesApi* | [**CreateCustomFields**](docs/EnvelopesApi.md#createcustomfields) | **POST** /v2/accounts/{accountId}/envelopes/{envelopeId}/custom_fields | Updates envelope custom fields for an envelope.
*EnvelopesApi* | [**CreateDocumentFields**](docs/EnvelopesApi.md#createdocumentfields) | **POST** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents/{documentId}/fields | Creates custom document fields in an existing envelope document.
*EnvelopesApi* | [**CreateEditView**](docs/EnvelopesApi.md#createeditview) | **POST** /v2/accounts/{accountId}/envelopes/{envelopeId}/views/edit | Returns a URL to the edit view UI.
*EnvelopesApi* | [**CreateEmailSettings**](docs/EnvelopesApi.md#createemailsettings) | **POST** /v2/accounts/{accountId}/envelopes/{envelopeId}/email_settings | Adds email setting overrides to an envelope.
*EnvelopesApi* | [**CreateEnvelope**](docs/EnvelopesApi.md#createenvelope) | **POST** /v2/accounts/{accountId}/envelopes | Creates an envelope.
*EnvelopesApi* | [**CreateLock**](docs/EnvelopesApi.md#createlock) | **POST** /v2/accounts/{accountId}/envelopes/{envelopeId}/lock | Lock an envelope.
*EnvelopesApi* | [**CreateRecipient**](docs/EnvelopesApi.md#createrecipient) | **POST** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients | Adds one or more recipients to an envelope.
*EnvelopesApi* | [**CreateRecipientView**](docs/EnvelopesApi.md#createrecipientview) | **POST** /v2/accounts/{accountId}/envelopes/{envelopeId}/views/recipient | Returns a URL to the recipient view UI.
*EnvelopesApi* | [**CreateSenderView**](docs/EnvelopesApi.md#createsenderview) | **POST** /v2/accounts/{accountId}/envelopes/{envelopeId}/views/sender | Returns a URL to the sender view UI.
*EnvelopesApi* | [**CreateTabs**](docs/EnvelopesApi.md#createtabs) | **POST** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId}/tabs | Adds tabs for a recipient.
*EnvelopesApi* | [**CreateViewLink**](docs/EnvelopesApi.md#createviewlink) | **POST** /v2/accounts/{accountId}/envelopes/{envelopeId}/views/viewlink | Reserved: Returns a URL to the secure link view UI.
*EnvelopesApi* | [**DeleteAttachments**](docs/EnvelopesApi.md#deleteattachments) | **DELETE** /v2/accounts/{accountId}/envelopes/{envelopeId}/attachments | Delete one or more attachments from a DRAFT envelope.
*EnvelopesApi* | [**DeleteChunkedUpload**](docs/EnvelopesApi.md#deletechunkedupload) | **DELETE** /v2/accounts/{accountId}/chunked_uploads/{chunkedUploadId} | Delete an existing ChunkedUpload.
*EnvelopesApi* | [**DeleteCustomFields**](docs/EnvelopesApi.md#deletecustomfields) | **DELETE** /v2/accounts/{accountId}/envelopes/{envelopeId}/custom_fields | Deletes envelope custom fields for draft and in-process envelopes.
*EnvelopesApi* | [**DeleteDocumentFields**](docs/EnvelopesApi.md#deletedocumentfields) | **DELETE** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents/{documentId}/fields | Deletes custom document fields from an existing envelope document.
*EnvelopesApi* | [**DeleteDocumentPage**](docs/EnvelopesApi.md#deletedocumentpage) | **DELETE** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents/{documentId}/pages/{pageNumber} | Deletes a page from a document in an envelope.
*EnvelopesApi* | [**DeleteDocuments**](docs/EnvelopesApi.md#deletedocuments) | **DELETE** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents | Deletes documents from a draft envelope.
*EnvelopesApi* | [**DeleteEmailSettings**](docs/EnvelopesApi.md#deleteemailsettings) | **DELETE** /v2/accounts/{accountId}/envelopes/{envelopeId}/email_settings | Deletes the email setting overrides for an envelope.
*EnvelopesApi* | [**DeleteLock**](docs/EnvelopesApi.md#deletelock) | **DELETE** /v2/accounts/{accountId}/envelopes/{envelopeId}/lock | Deletes an envelope lock.
*EnvelopesApi* | [**DeleteRecipient**](docs/EnvelopesApi.md#deleterecipient) | **DELETE** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId} | Deletes a recipient from an envelope.
*EnvelopesApi* | [**DeleteRecipients**](docs/EnvelopesApi.md#deleterecipients) | **DELETE** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients | Deletes recipients from an envelope.
*EnvelopesApi* | [**DeleteTabs**](docs/EnvelopesApi.md#deletetabs) | **DELETE** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId}/tabs | Deletes the tabs associated with a recipient.
*EnvelopesApi* | [**DeleteTemplatesFromDocument**](docs/EnvelopesApi.md#deletetemplatesfromdocument) | **DELETE** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents/{documentId}/templates/{templateId} | Deletes a template from a document in an existing envelope.
*EnvelopesApi* | [**DeleteViewLink**](docs/EnvelopesApi.md#deleteviewlink) | **DELETE** /v2/accounts/{accountId}/envelopes/{envelopeId}/views/viewlink | Reserved: Expires a secure view link.
*EnvelopesApi* | [**GetAttachment**](docs/EnvelopesApi.md#getattachment) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/attachments/{attachmentId} | Retrieves an attachment from the envelope.
*EnvelopesApi* | [**GetAttachments**](docs/EnvelopesApi.md#getattachments) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/attachments | Returns a list of attachments associated with the specified envelope
*EnvelopesApi* | [**GetChunkedUpload**](docs/EnvelopesApi.md#getchunkedupload) | **GET** /v2/accounts/{accountId}/chunked_uploads/{chunkedUploadId} | Retrieves the current metadata of a ChunkedUpload.
*EnvelopesApi* | [**GetConsumerDisclosure**](docs/EnvelopesApi.md#getconsumerdisclosure) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId}/consumer_disclosure/{langCode} | Reserved: Gets the Electronic Record and Signature Disclosure associated with the account.
*EnvelopesApi* | [**GetConsumerDisclosureDefault**](docs/EnvelopesApi.md#getconsumerdisclosuredefault) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId}/consumer_disclosure | Gets the Electronic Record and Signature Disclosure associated with the account.
*EnvelopesApi* | [**GetDocument**](docs/EnvelopesApi.md#getdocument) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents/{documentId} | Gets a document from an envelope.
*EnvelopesApi* | [**GetDocumentPageImage**](docs/EnvelopesApi.md#getdocumentpageimage) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents/{documentId}/pages/{pageNumber}/page_image | Gets a page image from an envelope for display.
*EnvelopesApi* | [**GetDocumentTabs**](docs/EnvelopesApi.md#getdocumenttabs) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents/{documentId}/tabs | Returns tabs on the document.
*EnvelopesApi* | [**GetEmailSettings**](docs/EnvelopesApi.md#getemailsettings) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/email_settings | Gets the email setting overrides for an envelope.
*EnvelopesApi* | [**GetEnvelope**](docs/EnvelopesApi.md#getenvelope) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId} | Gets the status of a envelope.
*EnvelopesApi* | [**GetFormData**](docs/EnvelopesApi.md#getformdata) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/form_data | Returns envelope form data for an existing envelope.
*EnvelopesApi* | [**GetLock**](docs/EnvelopesApi.md#getlock) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/lock | Gets envelope lock information.
*EnvelopesApi* | [**GetNotificationSettings**](docs/EnvelopesApi.md#getnotificationsettings) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/notification | Gets envelope notification information.
*EnvelopesApi* | [**GetPageTabs**](docs/EnvelopesApi.md#getpagetabs) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents/{documentId}/pages/{pageNumber}/tabs | Returns tabs on the specified page.
*EnvelopesApi* | [**GetPages**](docs/EnvelopesApi.md#getpages) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents/{documentId}/pages | Returns document page image(s) based on input.
*EnvelopesApi* | [**GetRecipientDocumentVisibility**](docs/EnvelopesApi.md#getrecipientdocumentvisibility) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId}/document_visibility | Returns document visibility for the recipients
*EnvelopesApi* | [**GetRecipientInitialsImage**](docs/EnvelopesApi.md#getrecipientinitialsimage) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId}/initials_image | Gets the initials image for a user.
*EnvelopesApi* | [**GetRecipientSignature**](docs/EnvelopesApi.md#getrecipientsignature) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId}/signature | Gets signature information for a signer or sign-in-person recipient.
*EnvelopesApi* | [**GetRecipientSignatureImage**](docs/EnvelopesApi.md#getrecipientsignatureimage) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId}/signature_image | Retrieve signature image information for a signer/sign-in-person recipient.
*EnvelopesApi* | [**GetTemplateRecipientDocumentVisibility**](docs/EnvelopesApi.md#gettemplaterecipientdocumentvisibility) | **GET** /v2/accounts/{accountId}/templates/{templateId}/recipients/{recipientId}/document_visibility | Returns document visibility for the recipients
*EnvelopesApi* | [**ListAuditEvents**](docs/EnvelopesApi.md#listauditevents) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/audit_events | Gets the envelope audit events for an envelope.
*EnvelopesApi* | [**ListCustomFields**](docs/EnvelopesApi.md#listcustomfields) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/custom_fields | Gets the custom field information for the specified envelope.
*EnvelopesApi* | [**ListDocumentFields**](docs/EnvelopesApi.md#listdocumentfields) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents/{documentId}/fields | Gets the custom document fields from an  existing envelope document.
*EnvelopesApi* | [**ListDocuments**](docs/EnvelopesApi.md#listdocuments) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents | Gets a list of envelope documents.
*EnvelopesApi* | [**ListRecipients**](docs/EnvelopesApi.md#listrecipients) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients | Gets the status of recipients for an envelope.
*EnvelopesApi* | [**ListStatus**](docs/EnvelopesApi.md#liststatus) | **PUT** /v2/accounts/{accountId}/envelopes/status | Gets the envelope status for the specified envelopes.
*EnvelopesApi* | [**ListStatusChanges**](docs/EnvelopesApi.md#liststatuschanges) | **GET** /v2/accounts/{accountId}/envelopes | Gets status changes for one or more envelopes.
*EnvelopesApi* | [**ListTabs**](docs/EnvelopesApi.md#listtabs) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId}/tabs | Gets the tabs information for a signer or sign-in-person recipient in an envelope.
*EnvelopesApi* | [**ListTemplates**](docs/EnvelopesApi.md#listtemplates) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/templates | Get List of Templates used in an Envelope
*EnvelopesApi* | [**ListTemplatesForDocument**](docs/EnvelopesApi.md#listtemplatesfordocument) | **GET** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents/{documentId}/templates | Gets the templates associated with a document in an existing envelope.
*EnvelopesApi* | [**PutAttachment**](docs/EnvelopesApi.md#putattachment) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/attachments/{attachmentId} | Add an attachment to a DRAFT or IN-PROCESS envelope.
*EnvelopesApi* | [**PutAttachments**](docs/EnvelopesApi.md#putattachments) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/attachments | Add one or more attachments to a DRAFT or IN-PROCESS envelope.
*EnvelopesApi* | [**RotateDocumentPage**](docs/EnvelopesApi.md#rotatedocumentpage) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents/{documentId}/pages/{pageNumber}/page_image | Rotates page image from an envelope for display.
*EnvelopesApi* | [**Update**](docs/EnvelopesApi.md#update) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId} | Send Draft Envelope/Void Envelope/Move/Purge Envelope/Modify draft
*EnvelopesApi* | [**UpdateChunkedUpload**](docs/EnvelopesApi.md#updatechunkedupload) | **PUT** /v2/accounts/{accountId}/chunked_uploads/{chunkedUploadId} | Integrity-Check and Commit a ChunkedUpload, readying it for use elsewhere.
*EnvelopesApi* | [**UpdateChunkedUploadPart**](docs/EnvelopesApi.md#updatechunkeduploadpart) | **PUT** /v2/accounts/{accountId}/chunked_uploads/{chunkedUploadId}/{chunkedUploadPartSeq} | Add a chunk, a chunk 'part', to an existing ChunkedUpload.
*EnvelopesApi* | [**UpdateCustomFields**](docs/EnvelopesApi.md#updatecustomfields) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/custom_fields | Updates envelope custom fields in an envelope.
*EnvelopesApi* | [**UpdateDocument**](docs/EnvelopesApi.md#updatedocument) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents/{documentId} | Adds a document to an existing draft envelope.
*EnvelopesApi* | [**UpdateDocumentFields**](docs/EnvelopesApi.md#updatedocumentfields) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents/{documentId}/fields | Updates existing custom document fields in an existing envelope document.
*EnvelopesApi* | [**UpdateDocuments**](docs/EnvelopesApi.md#updatedocuments) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/documents | Adds one or more documents to an existing envelope document.
*EnvelopesApi* | [**UpdateEmailSettings**](docs/EnvelopesApi.md#updateemailsettings) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/email_settings | Updates the email setting overrides for an envelope.
*EnvelopesApi* | [**UpdateLock**](docs/EnvelopesApi.md#updatelock) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/lock | Updates an envelope lock.
*EnvelopesApi* | [**UpdateNotificationSettings**](docs/EnvelopesApi.md#updatenotificationsettings) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/notification | Sets envelope notification (Reminders/Expirations) structure for an existing envelope.
*EnvelopesApi* | [**UpdateRecipientDocumentVisibility**](docs/EnvelopesApi.md#updaterecipientdocumentvisibility) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId}/document_visibility | Updates document visibility for the recipients
*EnvelopesApi* | [**UpdateRecipientInitialsImage**](docs/EnvelopesApi.md#updaterecipientinitialsimage) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId}/initials_image | Sets the initials image for an accountless signer.
*EnvelopesApi* | [**UpdateRecipientSignatureImage**](docs/EnvelopesApi.md#updaterecipientsignatureimage) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId}/signature_image | Sets the signature image for an accountless signer.
*EnvelopesApi* | [**UpdateRecipients**](docs/EnvelopesApi.md#updaterecipients) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients | Updates recipients in a draft envelope or corrects recipient information for an in process envelope.
*EnvelopesApi* | [**UpdateRecipientsDocumentVisibility**](docs/EnvelopesApi.md#updaterecipientsdocumentvisibility) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/document_visibility | Updates document visibility for the recipients
*EnvelopesApi* | [**UpdateTabs**](docs/EnvelopesApi.md#updatetabs) | **PUT** /v2/accounts/{accountId}/envelopes/{envelopeId}/recipients/{recipientId}/tabs | Updates the tabs for a recipient.  
*EnvelopesApi* | [**UpdateTemplateRecipientDocumentVisibility**](docs/EnvelopesApi.md#updatetemplaterecipientdocumentvisibility) | **PUT** /v2/accounts/{accountId}/templates/{templateId}/recipients/{recipientId}/document_visibility | Updates document visibility for the recipients
*EnvelopesApi* | [**UpdateTemplateRecipientsDocumentVisibility**](docs/EnvelopesApi.md#updatetemplaterecipientsdocumentvisibility) | **PUT** /v2/accounts/{accountId}/templates/{templateId}/recipients/document_visibility | Updates document visibility for the recipients
*FoldersApi* | [**List**](docs/FoldersApi.md#list) | **GET** /v2/accounts/{accountId}/folders | Gets a list of the folders for the account.
*FoldersApi* | [**ListItems**](docs/FoldersApi.md#listitems) | **GET** /v2/accounts/{accountId}/folders/{folderId} | Gets a list of the envelopes in the specified folder.
*FoldersApi* | [**MoveEnvelopes**](docs/FoldersApi.md#moveenvelopes) | **PUT** /v2/accounts/{accountId}/folders/{folderId} | Moves an envelope from its current folder to the specified folder.
*FoldersApi* | [**Search**](docs/FoldersApi.md#search) | **GET** /v2/accounts/{accountId}/search_folders/{searchFolderId} | Gets a list of envelopes in folders matching the specified criteria.
*GroupsApi* | [**CreateGroups**](docs/GroupsApi.md#creategroups) | **POST** /v2/accounts/{accountId}/groups | Creates one or more groups for the account.
*GroupsApi* | [**DeleteBrands**](docs/GroupsApi.md#deletebrands) | **DELETE** /v2/accounts/{accountId}/groups/{groupId}/brands | Deletes brand information from the requested group.
*GroupsApi* | [**DeleteGroupUsers**](docs/GroupsApi.md#deletegroupusers) | **DELETE** /v2/accounts/{accountId}/groups/{groupId}/users | Deletes one or more users from a gro
*GroupsApi* | [**DeleteGroups**](docs/GroupsApi.md#deletegroups) | **DELETE** /v2/accounts/{accountId}/groups | Deletes an existing user group.
*GroupsApi* | [**GetBrands**](docs/GroupsApi.md#getbrands) | **GET** /v2/accounts/{accountId}/groups/{groupId}/brands | Gets group brand ID Information. 
*GroupsApi* | [**ListGroupUsers**](docs/GroupsApi.md#listgroupusers) | **GET** /v2/accounts/{accountId}/groups/{groupId}/users | Gets a list of users in a group.
*GroupsApi* | [**ListGroups**](docs/GroupsApi.md#listgroups) | **GET** /v2/accounts/{accountId}/groups | Gets information about groups associated with the account.
*GroupsApi* | [**UpdateBrands**](docs/GroupsApi.md#updatebrands) | **PUT** /v2/accounts/{accountId}/groups/{groupId}/brands | Adds group brand ID information to a group.
*GroupsApi* | [**UpdateGroupUsers**](docs/GroupsApi.md#updategroupusers) | **PUT** /v2/accounts/{accountId}/groups/{groupId}/users | Adds one or more users to an existing group.
*GroupsApi* | [**UpdateGroups**](docs/GroupsApi.md#updategroups) | **PUT** /v2/accounts/{accountId}/groups | Updates the group information for a group.
*NotaryApi* | [**ListNotaryJournals**](docs/NotaryApi.md#listnotaryjournals) | **GET** /v2/current_user/notary/journals | Get notary jurisdictions for a user
*PowerFormsApi* | [**CreatePowerForm**](docs/PowerFormsApi.md#createpowerform) | **POST** /v2/accounts/{accountId}/powerforms | Creates a new PowerForm.
*PowerFormsApi* | [**DeletePowerForm**](docs/PowerFormsApi.md#deletepowerform) | **DELETE** /v2/accounts/{accountId}/powerforms/{powerFormId} | Delete a PowerForm.
*PowerFormsApi* | [**DeletePowerForms**](docs/PowerFormsApi.md#deletepowerforms) | **DELETE** /v2/accounts/{accountId}/powerforms | Deletes one or more PowerForms
*PowerFormsApi* | [**GetPowerForm**](docs/PowerFormsApi.md#getpowerform) | **GET** /v2/accounts/{accountId}/powerforms/{powerFormId} | Returns a single PowerForm.
*PowerFormsApi* | [**GetPowerFormData**](docs/PowerFormsApi.md#getpowerformdata) | **GET** /v2/accounts/{accountId}/powerforms/{powerFormId}/form_data | Returns the form data associated with the usage of a PowerForm.
*PowerFormsApi* | [**ListPowerFormSenders**](docs/PowerFormsApi.md#listpowerformsenders) | **GET** /v2/accounts/{accountId}/powerforms/senders | Returns the list of PowerForms available to the user.
*PowerFormsApi* | [**ListPowerForms**](docs/PowerFormsApi.md#listpowerforms) | **GET** /v2/accounts/{accountId}/powerforms | Returns the list of PowerForms available to the user.
*PowerFormsApi* | [**UpdatePowerForm**](docs/PowerFormsApi.md#updatepowerform) | **PUT** /v2/accounts/{accountId}/powerforms/{powerFormId} | Creates a new PowerForm.
*SigningGroupsApi* | [**CreateList**](docs/SigningGroupsApi.md#createlist) | **POST** /v2/accounts/{accountId}/signing_groups | Creates a signing group. 
*SigningGroupsApi* | [**DeleteList**](docs/SigningGroupsApi.md#deletelist) | **DELETE** /v2/accounts/{accountId}/signing_groups | Deletes one or more signing groups.
*SigningGroupsApi* | [**DeleteUsers**](docs/SigningGroupsApi.md#deleteusers) | **DELETE** /v2/accounts/{accountId}/signing_groups/{signingGroupId}/users | Deletes  one or more members from a signing group.
*SigningGroupsApi* | [**Get**](docs/SigningGroupsApi.md#get) | **GET** /v2/accounts/{accountId}/signing_groups/{signingGroupId} | Gets information about a signing group. 
*SigningGroupsApi* | [**List**](docs/SigningGroupsApi.md#list) | **GET** /v2/accounts/{accountId}/signing_groups | Gets a list of the Signing Groups in an account.
*SigningGroupsApi* | [**ListUsers**](docs/SigningGroupsApi.md#listusers) | **GET** /v2/accounts/{accountId}/signing_groups/{signingGroupId}/users | Gets a list of members in a Signing Group.
*SigningGroupsApi* | [**Update**](docs/SigningGroupsApi.md#update) | **PUT** /v2/accounts/{accountId}/signing_groups/{signingGroupId} | Updates a signing group. 
*SigningGroupsApi* | [**UpdateList**](docs/SigningGroupsApi.md#updatelist) | **PUT** /v2/accounts/{accountId}/signing_groups | Updates signing group names.
*SigningGroupsApi* | [**UpdateUsers**](docs/SigningGroupsApi.md#updateusers) | **PUT** /v2/accounts/{accountId}/signing_groups/{signingGroupId}/users | Adds members to a signing group. 
*TemplatesApi* | [**CreateCustomFields**](docs/TemplatesApi.md#createcustomfields) | **POST** /v2/accounts/{accountId}/templates/{templateId}/custom_fields | Creates custom document fields in an existing template document.
*TemplatesApi* | [**CreateDocumentFields**](docs/TemplatesApi.md#createdocumentfields) | **POST** /v2/accounts/{accountId}/templates/{templateId}/documents/{documentId}/fields | Creates custom document fields in an existing template document.
*TemplatesApi* | [**CreateEditView**](docs/TemplatesApi.md#createeditview) | **POST** /v2/accounts/{accountId}/templates/{templateId}/views/edit | Provides a URL to start an edit view of the Template UI
*TemplatesApi* | [**CreateLock**](docs/TemplatesApi.md#createlock) | **POST** /v2/accounts/{accountId}/templates/{templateId}/lock | Lock a template.
*TemplatesApi* | [**CreateRecipients**](docs/TemplatesApi.md#createrecipients) | **POST** /v2/accounts/{accountId}/templates/{templateId}/recipients | Adds tabs for a recipient.
*TemplatesApi* | [**CreateTabs**](docs/TemplatesApi.md#createtabs) | **POST** /v2/accounts/{accountId}/templates/{templateId}/recipients/{recipientId}/tabs | Adds tabs for a recipient.
*TemplatesApi* | [**CreateTemplate**](docs/TemplatesApi.md#createtemplate) | **POST** /v2/accounts/{accountId}/templates | Creates an envelope from a template.
*TemplatesApi* | [**DeleteBulkRecipients**](docs/TemplatesApi.md#deletebulkrecipients) | **DELETE** /v2/accounts/{accountId}/templates/{templateId}/recipients/{recipientId}/bulk_recipients | Deletes the bulk recipient list on a template.
*TemplatesApi* | [**DeleteCustomFields**](docs/TemplatesApi.md#deletecustomfields) | **DELETE** /v2/accounts/{accountId}/templates/{templateId}/custom_fields | Deletes envelope custom fields in a template.
*TemplatesApi* | [**DeleteDocumentFields**](docs/TemplatesApi.md#deletedocumentfields) | **DELETE** /v2/accounts/{accountId}/templates/{templateId}/documents/{documentId}/fields | Deletes custom document fields from an existing template document.
*TemplatesApi* | [**DeleteDocumentPage**](docs/TemplatesApi.md#deletedocumentpage) | **DELETE** /v2/accounts/{accountId}/templates/{templateId}/documents/{documentId}/pages/{pageNumber} | Deletes a page from a document in an template.
*TemplatesApi* | [**DeleteDocuments**](docs/TemplatesApi.md#deletedocuments) | **DELETE** /v2/accounts/{accountId}/templates/{templateId}/documents | Deletes documents from a template.
*TemplatesApi* | [**DeleteGroupShare**](docs/TemplatesApi.md#deletegroupshare) | **DELETE** /v2/accounts/{accountId}/templates/{templateId}/{templatePart} | Removes a member group's sharing permissions for a template.
*TemplatesApi* | [**DeleteLock**](docs/TemplatesApi.md#deletelock) | **DELETE** /v2/accounts/{accountId}/templates/{templateId}/lock | Deletes a template lock.
*TemplatesApi* | [**DeleteRecipient**](docs/TemplatesApi.md#deleterecipient) | **DELETE** /v2/accounts/{accountId}/templates/{templateId}/recipients/{recipientId} | Deletes the specified recipient file from a template.
*TemplatesApi* | [**DeleteRecipients**](docs/TemplatesApi.md#deleterecipients) | **DELETE** /v2/accounts/{accountId}/templates/{templateId}/recipients | Deletes recipients from a template.
*TemplatesApi* | [**DeleteTabs**](docs/TemplatesApi.md#deletetabs) | **DELETE** /v2/accounts/{accountId}/templates/{templateId}/recipients/{recipientId}/tabs | Deletes the tabs associated with a recipient in a template.
*TemplatesApi* | [**Get**](docs/TemplatesApi.md#get) | **GET** /v2/accounts/{accountId}/templates/{templateId} | Gets a list of templates for a specified account.
*TemplatesApi* | [**GetDocument**](docs/TemplatesApi.md#getdocument) | **GET** /v2/accounts/{accountId}/templates/{templateId}/documents/{documentId} | Gets PDF documents from a template.
*TemplatesApi* | [**GetDocumentPageImage**](docs/TemplatesApi.md#getdocumentpageimage) | **GET** /v2/accounts/{accountId}/templates/{templateId}/documents/{documentId}/pages/{pageNumber}/page_image | Gets a page image from a template for display.
*TemplatesApi* | [**GetDocumentTabs**](docs/TemplatesApi.md#getdocumenttabs) | **GET** /v2/accounts/{accountId}/templates/{templateId}/documents/{documentId}/tabs | Returns tabs on the document.
*TemplatesApi* | [**GetLock**](docs/TemplatesApi.md#getlock) | **GET** /v2/accounts/{accountId}/templates/{templateId}/lock | Gets template lock information.
*TemplatesApi* | [**GetNotificationSettings**](docs/TemplatesApi.md#getnotificationsettings) | **GET** /v2/accounts/{accountId}/templates/{templateId}/notification | Gets template notification information.
*TemplatesApi* | [**GetPageTabs**](docs/TemplatesApi.md#getpagetabs) | **GET** /v2/accounts/{accountId}/templates/{templateId}/documents/{documentId}/pages/{pageNumber}/tabs | Returns tabs on the specified page.
*TemplatesApi* | [**GetPages**](docs/TemplatesApi.md#getpages) | **GET** /v2/accounts/{accountId}/templates/{templateId}/documents/{documentId}/pages | Returns document page image(s) based on input.
*TemplatesApi* | [**ListBulkRecipients**](docs/TemplatesApi.md#listbulkrecipients) | **GET** /v2/accounts/{accountId}/templates/{templateId}/recipients/{recipientId}/bulk_recipients | Gets the bulk recipient file from a template.
*TemplatesApi* | [**ListCustomFields**](docs/TemplatesApi.md#listcustomfields) | **GET** /v2/accounts/{accountId}/templates/{templateId}/custom_fields | Gets the custom document fields from a template.
*TemplatesApi* | [**ListDocumentFields**](docs/TemplatesApi.md#listdocumentfields) | **GET** /v2/accounts/{accountId}/templates/{templateId}/documents/{documentId}/fields | Gets the custom document fields for a an existing template document.
*TemplatesApi* | [**ListDocuments**](docs/TemplatesApi.md#listdocuments) | **GET** /v2/accounts/{accountId}/templates/{templateId}/documents | Gets a list of documents associated with a template.
*TemplatesApi* | [**ListRecipients**](docs/TemplatesApi.md#listrecipients) | **GET** /v2/accounts/{accountId}/templates/{templateId}/recipients | Gets recipient information from a template.
*TemplatesApi* | [**ListTabs**](docs/TemplatesApi.md#listtabs) | **GET** /v2/accounts/{accountId}/templates/{templateId}/recipients/{recipientId}/tabs | Gets the tabs information for a signer or sign-in-person recipient in a template.
*TemplatesApi* | [**ListTemplates**](docs/TemplatesApi.md#listtemplates) | **GET** /v2/accounts/{accountId}/templates | Gets the definition of a template.
*TemplatesApi* | [**RotateDocumentPage**](docs/TemplatesApi.md#rotatedocumentpage) | **PUT** /v2/accounts/{accountId}/templates/{templateId}/documents/{documentId}/pages/{pageNumber}/page_image | Rotates page image from a template for display.
*TemplatesApi* | [**Update**](docs/TemplatesApi.md#update) | **PUT** /v2/accounts/{accountId}/templates/{templateId} | Updates an existing template.
*TemplatesApi* | [**UpdateBulkRecipients**](docs/TemplatesApi.md#updatebulkrecipients) | **PUT** /v2/accounts/{accountId}/templates/{templateId}/recipients/{recipientId}/bulk_recipients | Adds or replaces the bulk recipients list in a template.
*TemplatesApi* | [**UpdateCustomFields**](docs/TemplatesApi.md#updatecustomfields) | **PUT** /v2/accounts/{accountId}/templates/{templateId}/custom_fields | Updates envelope custom fields in a template.
*TemplatesApi* | [**UpdateDocument**](docs/TemplatesApi.md#updatedocument) | **PUT** /v2/accounts/{accountId}/templates/{templateId}/documents/{documentId} | Adds a document to a template document.
*TemplatesApi* | [**UpdateDocumentFields**](docs/TemplatesApi.md#updatedocumentfields) | **PUT** /v2/accounts/{accountId}/templates/{templateId}/documents/{documentId}/fields | Updates existing custom document fields in an existing template document.
*TemplatesApi* | [**UpdateDocuments**](docs/TemplatesApi.md#updatedocuments) | **PUT** /v2/accounts/{accountId}/templates/{templateId}/documents | Adds documents to a template document.
*TemplatesApi* | [**UpdateGroupShare**](docs/TemplatesApi.md#updategroupshare) | **PUT** /v2/accounts/{accountId}/templates/{templateId}/{templatePart} | Shares a template with a group
*TemplatesApi* | [**UpdateLock**](docs/TemplatesApi.md#updatelock) | **PUT** /v2/accounts/{accountId}/templates/{templateId}/lock | Updates a template lock.
*TemplatesApi* | [**UpdateNotificationSettings**](docs/TemplatesApi.md#updatenotificationsettings) | **PUT** /v2/accounts/{accountId}/templates/{templateId}/notification | Updates the notification  structure for an existing template.
*TemplatesApi* | [**UpdateRecipients**](docs/TemplatesApi.md#updaterecipients) | **PUT** /v2/accounts/{accountId}/templates/{templateId}/recipients | Updates recipients in a template.
*TemplatesApi* | [**UpdateTabs**](docs/TemplatesApi.md#updatetabs) | **PUT** /v2/accounts/{accountId}/templates/{templateId}/recipients/{recipientId}/tabs | Updates the tabs for a recipient.
*TrustServiceProvidersApi* | [**CompleteSignHash**](docs/TrustServiceProvidersApi.md#completesignhash) | **POST** /v2/signature/completesignhash | Complete Sign Hash
*TrustServiceProvidersApi* | [**GetUserInfo**](docs/TrustServiceProvidersApi.md#getuserinfo) | **GET** /v2/signature/userInfo | Get User Info To Sign Document
*TrustServiceProvidersApi* | [**HealthCheck**](docs/TrustServiceProvidersApi.md#healthcheck) | **POST** /v2/signature/healthcheck | Report status from the TSP to DocuSign
*TrustServiceProvidersApi* | [**SignHashSessionInfo**](docs/TrustServiceProvidersApi.md#signhashsessioninfo) | **POST** /v2/signature/signhashsessioninfo | Get Signature Session Info To Sign Document Hash
*TrustServiceProvidersApi* | [**UpdateTransaction**](docs/TrustServiceProvidersApi.md#updatetransaction) | **POST** /v2/signature/updatetransaction | Report an error from the tsp to docusign
*UsersApi* | [**Create**](docs/UsersApi.md#create) | **POST** /v2/accounts/{accountId}/users | Adds news user to the specified account.
*UsersApi* | [**CreateSignatures**](docs/UsersApi.md#createsignatures) | **POST** /v2/accounts/{accountId}/users/{userId}/signatures | Adds user Signature and initials images to a Signature.
*UsersApi* | [**Delete**](docs/UsersApi.md#delete) | **DELETE** /v2/accounts/{accountId}/users | Removes users account privileges.
*UsersApi* | [**DeleteContactWithId**](docs/UsersApi.md#deletecontactwithid) | **DELETE** /v2/accounts/{accountId}/contacts/{contactId} | Replaces a particular contact associated with an account for the DocuSign service.
*UsersApi* | [**DeleteContacts**](docs/UsersApi.md#deletecontacts) | **DELETE** /v2/accounts/{accountId}/contacts | Delete contacts associated with an account for the DocuSign service.
*UsersApi* | [**DeleteCustomSettings**](docs/UsersApi.md#deletecustomsettings) | **DELETE** /v2/accounts/{accountId}/users/{userId}/custom_settings | Deletes custom user settings for a specified user.
*UsersApi* | [**DeleteProfileImage**](docs/UsersApi.md#deleteprofileimage) | **DELETE** /v2/accounts/{accountId}/users/{userId}/profile/image | Deletes the user profile image for the specified user.
*UsersApi* | [**DeleteSignature**](docs/UsersApi.md#deletesignature) | **DELETE** /v2/accounts/{accountId}/users/{userId}/signatures/{signatureId} | Removes removes signature information for the specified user.
*UsersApi* | [**DeleteSignatureImage**](docs/UsersApi.md#deletesignatureimage) | **DELETE** /v2/accounts/{accountId}/users/{userId}/signatures/{signatureId}/{imageType} | Deletes the user initials image or the  user signature image for the specified user.
*UsersApi* | [**GetContactById**](docs/UsersApi.md#getcontactbyid) | **GET** /v2/accounts/{accountId}/contacts/{contactId} | Gets a particular contact associated with the user's account.
*UsersApi* | [**GetInformation**](docs/UsersApi.md#getinformation) | **GET** /v2/accounts/{accountId}/users/{userId} | Gets the user information for a specified user.
*UsersApi* | [**GetProfile**](docs/UsersApi.md#getprofile) | **GET** /v2/accounts/{accountId}/users/{userId}/profile | Retrieves the user profile for a specified user.
*UsersApi* | [**GetProfileImage**](docs/UsersApi.md#getprofileimage) | **GET** /v2/accounts/{accountId}/users/{userId}/profile/image | Retrieves the user profile image for the specified user.
*UsersApi* | [**GetSettings**](docs/UsersApi.md#getsettings) | **GET** /v2/accounts/{accountId}/users/{userId}/settings | Gets the user account settings for a specified user.
*UsersApi* | [**GetSignature**](docs/UsersApi.md#getsignature) | **GET** /v2/accounts/{accountId}/users/{userId}/signatures/{signatureId} | Gets the user signature information for the specified user.
*UsersApi* | [**GetSignatureImage**](docs/UsersApi.md#getsignatureimage) | **GET** /v2/accounts/{accountId}/users/{userId}/signatures/{signatureId}/{imageType} | Retrieves the user initials image or the  user signature image for the specified user.
*UsersApi* | [**List**](docs/UsersApi.md#list) | **GET** /v2/accounts/{accountId}/users | Retrieves the list of users for the specified account.
*UsersApi* | [**ListCustomSettings**](docs/UsersApi.md#listcustomsettings) | **GET** /v2/accounts/{accountId}/users/{userId}/custom_settings | Retrieves the custom user settings for a specified user.
*UsersApi* | [**ListSignatures**](docs/UsersApi.md#listsignatures) | **GET** /v2/accounts/{accountId}/users/{userId}/signatures | Retrieves a list of user signature definitions for a specified user.
*UsersApi* | [**PostContacts**](docs/UsersApi.md#postcontacts) | **POST** /v2/accounts/{accountId}/contacts | Imports multiple new contacts into the contacts collection from CSV, JSON, or XML (based on content type).
*UsersApi* | [**PutContacts**](docs/UsersApi.md#putcontacts) | **PUT** /v2/accounts/{accountId}/contacts | Replaces contacts associated with an account for the DocuSign service.
*UsersApi* | [**UpdateCustomSettings**](docs/UsersApi.md#updatecustomsettings) | **PUT** /v2/accounts/{accountId}/users/{userId}/custom_settings | Adds or updates custom user settings for the specified user.
*UsersApi* | [**UpdateProfile**](docs/UsersApi.md#updateprofile) | **PUT** /v2/accounts/{accountId}/users/{userId}/profile | Updates the user profile information for the specified user.
*UsersApi* | [**UpdateProfileImage**](docs/UsersApi.md#updateprofileimage) | **PUT** /v2/accounts/{accountId}/users/{userId}/profile/image | Updates the user profile image for a specified user.
*UsersApi* | [**UpdateSettings**](docs/UsersApi.md#updatesettings) | **PUT** /v2/accounts/{accountId}/users/{userId}/settings | Updates the user account settings for a specified user.
*UsersApi* | [**UpdateSignature**](docs/UsersApi.md#updatesignature) | **PUT** /v2/accounts/{accountId}/users/{userId}/signatures/{signatureId} | Updates the user signature for a specified user.
*UsersApi* | [**UpdateSignatureImage**](docs/UsersApi.md#updatesignatureimage) | **PUT** /v2/accounts/{accountId}/users/{userId}/signatures/{signatureId}/{imageType} | Updates the user signature image or user initials image for the specified user.
*UsersApi* | [**UpdateSignatures**](docs/UsersApi.md#updatesignatures) | **PUT** /v2/accounts/{accountId}/users/{userId}/signatures | Adds/updates a user signature.
*UsersApi* | [**UpdateUser**](docs/UsersApi.md#updateuser) | **PUT** /v2/accounts/{accountId}/users/{userId} | Updates the specified user information.
*UsersApi* | [**UpdateUsers**](docs/UsersApi.md#updateusers) | **PUT** /v2/accounts/{accountId}/users | Change one or more user in the specified account.
*WorkspacesApi* | [**CreateWorkspace**](docs/WorkspacesApi.md#createworkspace) | **POST** /v2/accounts/{accountId}/workspaces | Create a Workspace
*WorkspacesApi* | [**CreateWorkspaceFile**](docs/WorkspacesApi.md#createworkspacefile) | **POST** /v2/accounts/{accountId}/workspaces/{workspaceId}/folders/{folderId}/files | Creates a workspace file.
*WorkspacesApi* | [**DeleteWorkspace**](docs/WorkspacesApi.md#deleteworkspace) | **DELETE** /v2/accounts/{accountId}/workspaces/{workspaceId} | Delete Workspace
*WorkspacesApi* | [**DeleteWorkspaceFolderItems**](docs/WorkspacesApi.md#deleteworkspacefolderitems) | **DELETE** /v2/accounts/{accountId}/workspaces/{workspaceId}/folders/{folderId} | Deletes workspace one or more specific files/folders from the given folder or root.
*WorkspacesApi* | [**GetWorkspace**](docs/WorkspacesApi.md#getworkspace) | **GET** /v2/accounts/{accountId}/workspaces/{workspaceId} | Get Workspace
*WorkspacesApi* | [**GetWorkspaceFile**](docs/WorkspacesApi.md#getworkspacefile) | **GET** /v2/accounts/{accountId}/workspaces/{workspaceId}/folders/{folderId}/files/{fileId} | Get Workspace File
*WorkspacesApi* | [**ListWorkspaceFilePages**](docs/WorkspacesApi.md#listworkspacefilepages) | **GET** /v2/accounts/{accountId}/workspaces/{workspaceId}/folders/{folderId}/files/{fileId}/pages | List File Pages
*WorkspacesApi* | [**ListWorkspaceFolderItems**](docs/WorkspacesApi.md#listworkspacefolderitems) | **GET** /v2/accounts/{accountId}/workspaces/{workspaceId}/folders/{folderId} | List Workspace Folder Contents
*WorkspacesApi* | [**ListWorkspaces**](docs/WorkspacesApi.md#listworkspaces) | **GET** /v2/accounts/{accountId}/workspaces | List Workspaces
*WorkspacesApi* | [**UpdateWorkspace**](docs/WorkspacesApi.md#updateworkspace) | **PUT** /v2/accounts/{accountId}/workspaces/{workspaceId} | Update Workspace
*WorkspacesApi* | [**UpdateWorkspaceFile**](docs/WorkspacesApi.md#updateworkspacefile) | **PUT** /v2/accounts/{accountId}/workspaces/{workspaceId}/folders/{folderId}/files/{fileId} | Update Workspace File Metadata


<a name="documentation-for-models"></a>
## Documentation for Models

 - [Model.AccountAddress](docs/AccountAddress.md)
 - [Model.AccountBillingPlan](docs/AccountBillingPlan.md)
 - [Model.AccountBillingPlanResponse](docs/AccountBillingPlanResponse.md)
 - [Model.AccountInformation](docs/AccountInformation.md)
 - [Model.AccountMinimumPasswordLength](docs/AccountMinimumPasswordLength.md)
 - [Model.AccountPasswordExpirePasswordDays](docs/AccountPasswordExpirePasswordDays.md)
 - [Model.AccountPasswordLockoutDurationMinutes](docs/AccountPasswordLockoutDurationMinutes.md)
 - [Model.AccountPasswordLockoutDurationType](docs/AccountPasswordLockoutDurationType.md)
 - [Model.AccountPasswordMinimumPasswordAgeDays](docs/AccountPasswordMinimumPasswordAgeDays.md)
 - [Model.AccountPasswordQuestionsRequired](docs/AccountPasswordQuestionsRequired.md)
 - [Model.AccountPasswordRules](docs/AccountPasswordRules.md)
 - [Model.AccountPasswordStrengthType](docs/AccountPasswordStrengthType.md)
 - [Model.AccountPasswordStrengthTypeOption](docs/AccountPasswordStrengthTypeOption.md)
 - [Model.AccountRoleSettings](docs/AccountRoleSettings.md)
 - [Model.AccountSettingsInformation](docs/AccountSettingsInformation.md)
 - [Model.AccountSharedAccess](docs/AccountSharedAccess.md)
 - [Model.AccountSignatureProvider](docs/AccountSignatureProvider.md)
 - [Model.AccountSignatureProviderOption](docs/AccountSignatureProviderOption.md)
 - [Model.AccountSignatureProviders](docs/AccountSignatureProviders.md)
 - [Model.AddOn](docs/AddOn.md)
 - [Model.AddressInformation](docs/AddressInformation.md)
 - [Model.AddressInformationInput](docs/AddressInformationInput.md)
 - [Model.AddressInformationV2](docs/AddressInformationV2.md)
 - [Model.Agent](docs/Agent.md)
 - [Model.ApiRequestLog](docs/ApiRequestLog.md)
 - [Model.ApiRequestLogsResult](docs/ApiRequestLogsResult.md)
 - [Model.AppStoreProduct](docs/AppStoreProduct.md)
 - [Model.AppStoreReceipt](docs/AppStoreReceipt.md)
 - [Model.Approve](docs/Approve.md)
 - [Model.Attachment](docs/Attachment.md)
 - [Model.AuthenticationMethod](docs/AuthenticationMethod.md)
 - [Model.AuthenticationStatus](docs/AuthenticationStatus.md)
 - [Model.BccEmailAddress](docs/BccEmailAddress.md)
 - [Model.BillingCharge](docs/BillingCharge.md)
 - [Model.BillingChargeResponse](docs/BillingChargeResponse.md)
 - [Model.BillingDiscount](docs/BillingDiscount.md)
 - [Model.BillingInvoice](docs/BillingInvoice.md)
 - [Model.BillingInvoiceItem](docs/BillingInvoiceItem.md)
 - [Model.BillingInvoicesResponse](docs/BillingInvoicesResponse.md)
 - [Model.BillingInvoicesSummary](docs/BillingInvoicesSummary.md)
 - [Model.BillingPayment](docs/BillingPayment.md)
 - [Model.BillingPaymentItem](docs/BillingPaymentItem.md)
 - [Model.BillingPaymentRequest](docs/BillingPaymentRequest.md)
 - [Model.BillingPaymentResponse](docs/BillingPaymentResponse.md)
 - [Model.BillingPaymentsResponse](docs/BillingPaymentsResponse.md)
 - [Model.BillingPlan](docs/BillingPlan.md)
 - [Model.BillingPlanInformation](docs/BillingPlanInformation.md)
 - [Model.BillingPlanPreview](docs/BillingPlanPreview.md)
 - [Model.BillingPlanResponse](docs/BillingPlanResponse.md)
 - [Model.BillingPlanUpdateResponse](docs/BillingPlanUpdateResponse.md)
 - [Model.BillingPlansResponse](docs/BillingPlansResponse.md)
 - [Model.BillingPrice](docs/BillingPrice.md)
 - [Model.Brand](docs/Brand.md)
 - [Model.BrandEmailContent](docs/BrandEmailContent.md)
 - [Model.BrandLink](docs/BrandLink.md)
 - [Model.BrandLogos](docs/BrandLogos.md)
 - [Model.BrandRequest](docs/BrandRequest.md)
 - [Model.BrandResourceUrls](docs/BrandResourceUrls.md)
 - [Model.BrandResources](docs/BrandResources.md)
 - [Model.BrandResourcesList](docs/BrandResourcesList.md)
 - [Model.BrandsRequest](docs/BrandsRequest.md)
 - [Model.BrandsResponse](docs/BrandsResponse.md)
 - [Model.BulkEnvelope](docs/BulkEnvelope.md)
 - [Model.BulkEnvelopeStatus](docs/BulkEnvelopeStatus.md)
 - [Model.BulkEnvelopesResponse](docs/BulkEnvelopesResponse.md)
 - [Model.BulkRecipient](docs/BulkRecipient.md)
 - [Model.BulkRecipientSignatureProvider](docs/BulkRecipientSignatureProvider.md)
 - [Model.BulkRecipientTabLabel](docs/BulkRecipientTabLabel.md)
 - [Model.BulkRecipientsRequest](docs/BulkRecipientsRequest.md)
 - [Model.BulkRecipientsResponse](docs/BulkRecipientsResponse.md)
 - [Model.BulkRecipientsSummaryResponse](docs/BulkRecipientsSummaryResponse.md)
 - [Model.BulkRecipientsUpdateResponse](docs/BulkRecipientsUpdateResponse.md)
 - [Model.CaptiveRecipient](docs/CaptiveRecipient.md)
 - [Model.CaptiveRecipientInformation](docs/CaptiveRecipientInformation.md)
 - [Model.CarbonCopy](docs/CarbonCopy.md)
 - [Model.CertifiedDelivery](docs/CertifiedDelivery.md)
 - [Model.Checkbox](docs/Checkbox.md)
 - [Model.ChunkedUploadPart](docs/ChunkedUploadPart.md)
 - [Model.ChunkedUploadRequest](docs/ChunkedUploadRequest.md)
 - [Model.ChunkedUploadResponse](docs/ChunkedUploadResponse.md)
 - [Model.CloudStorageProvider](docs/CloudStorageProvider.md)
 - [Model.CloudStorageProviders](docs/CloudStorageProviders.md)
 - [Model.Company](docs/Company.md)
 - [Model.CompleteSignHashResponse](docs/CompleteSignHashResponse.md)
 - [Model.CompleteSignRequest](docs/CompleteSignRequest.md)
 - [Model.CompositeTemplate](docs/CompositeTemplate.md)
 - [Model.ConnectConfigResults](docs/ConnectConfigResults.md)
 - [Model.ConnectCustomConfiguration](docs/ConnectCustomConfiguration.md)
 - [Model.ConnectDebugLog](docs/ConnectDebugLog.md)
 - [Model.ConnectFailureFilter](docs/ConnectFailureFilter.md)
 - [Model.ConnectFailureResult](docs/ConnectFailureResult.md)
 - [Model.ConnectFailureResults](docs/ConnectFailureResults.md)
 - [Model.ConnectLog](docs/ConnectLog.md)
 - [Model.ConnectLogs](docs/ConnectLogs.md)
 - [Model.ConsoleViewRequest](docs/ConsoleViewRequest.md)
 - [Model.ConsumerDisclosure](docs/ConsumerDisclosure.md)
 - [Model.Contact](docs/Contact.md)
 - [Model.ContactGetResponse](docs/ContactGetResponse.md)
 - [Model.ContactModRequest](docs/ContactModRequest.md)
 - [Model.ContactPhoneNumber](docs/ContactPhoneNumber.md)
 - [Model.ContactUpdateResponse](docs/ContactUpdateResponse.md)
 - [Model.CorrectViewRequest](docs/CorrectViewRequest.md)
 - [Model.Country](docs/Country.md)
 - [Model.Credential](docs/Credential.md)
 - [Model.CreditCardInformation](docs/CreditCardInformation.md)
 - [Model.CreditCardTypes](docs/CreditCardTypes.md)
 - [Model.CurrencyFeatureSetPrice](docs/CurrencyFeatureSetPrice.md)
 - [Model.CurrencyPlanPrice](docs/CurrencyPlanPrice.md)
 - [Model.CustomField](docs/CustomField.md)
 - [Model.CustomFieldV2](docs/CustomFieldV2.md)
 - [Model.CustomFields](docs/CustomFields.md)
 - [Model.CustomFieldsEnvelope](docs/CustomFieldsEnvelope.md)
 - [Model.CustomSettingsInformation](docs/CustomSettingsInformation.md)
 - [Model.Date](docs/Date.md)
 - [Model.DateSigned](docs/DateSigned.md)
 - [Model.DateStampProperties](docs/DateStampProperties.md)
 - [Model.Decline](docs/Decline.md)
 - [Model.DiagnosticsSettingsInformation](docs/DiagnosticsSettingsInformation.md)
 - [Model.DobInformationInput](docs/DobInformationInput.md)
 - [Model.Document](docs/Document.md)
 - [Model.DocumentFieldsInformation](docs/DocumentFieldsInformation.md)
 - [Model.DocumentSecurityStore](docs/DocumentSecurityStore.md)
 - [Model.DocumentTemplate](docs/DocumentTemplate.md)
 - [Model.DocumentTemplateList](docs/DocumentTemplateList.md)
 - [Model.DocumentUpdateInfo](docs/DocumentUpdateInfo.md)
 - [Model.DocumentVisibility](docs/DocumentVisibility.md)
 - [Model.DocumentVisibilityList](docs/DocumentVisibilityList.md)
 - [Model.ENoteConfiguration](docs/ENoteConfiguration.md)
 - [Model.Editor](docs/Editor.md)
 - [Model.Email](docs/Email.md)
 - [Model.EmailAddress](docs/EmailAddress.md)
 - [Model.EmailSettings](docs/EmailSettings.md)
 - [Model.Envelope](docs/Envelope.md)
 - [Model.EnvelopeAttachment](docs/EnvelopeAttachment.md)
 - [Model.EnvelopeAttachmentsRequest](docs/EnvelopeAttachmentsRequest.md)
 - [Model.EnvelopeAttachmentsResult](docs/EnvelopeAttachmentsResult.md)
 - [Model.EnvelopeAuditEvent](docs/EnvelopeAuditEvent.md)
 - [Model.EnvelopeAuditEventResponse](docs/EnvelopeAuditEventResponse.md)
 - [Model.EnvelopeDefinition](docs/EnvelopeDefinition.md)
 - [Model.EnvelopeDocument](docs/EnvelopeDocument.md)
 - [Model.EnvelopeDocumentsResult](docs/EnvelopeDocumentsResult.md)
 - [Model.EnvelopeEvent](docs/EnvelopeEvent.md)
 - [Model.EnvelopeFormData](docs/EnvelopeFormData.md)
 - [Model.EnvelopeId](docs/EnvelopeId.md)
 - [Model.EnvelopeIdsRequest](docs/EnvelopeIdsRequest.md)
 - [Model.EnvelopeNotificationRequest](docs/EnvelopeNotificationRequest.md)
 - [Model.EnvelopeSummary](docs/EnvelopeSummary.md)
 - [Model.EnvelopeTemplate](docs/EnvelopeTemplate.md)
 - [Model.EnvelopeTemplateDefinition](docs/EnvelopeTemplateDefinition.md)
 - [Model.EnvelopeTemplateResult](docs/EnvelopeTemplateResult.md)
 - [Model.EnvelopeTemplateResults](docs/EnvelopeTemplateResults.md)
 - [Model.EnvelopeTransactionStatus](docs/EnvelopeTransactionStatus.md)
 - [Model.EnvelopeUpdateSummary](docs/EnvelopeUpdateSummary.md)
 - [Model.EnvelopesInformation](docs/EnvelopesInformation.md)
 - [Model.ErrorDetails](docs/ErrorDetails.md)
 - [Model.EventNotification](docs/EventNotification.md)
 - [Model.EventResult](docs/EventResult.md)
 - [Model.Expirations](docs/Expirations.md)
 - [Model.ExternalDocServiceErrorDetails](docs/ExternalDocServiceErrorDetails.md)
 - [Model.ExternalFile](docs/ExternalFile.md)
 - [Model.ExternalFolder](docs/ExternalFolder.md)
 - [Model.FeatureSet](docs/FeatureSet.md)
 - [Model.FileType](docs/FileType.md)
 - [Model.FileTypeList](docs/FileTypeList.md)
 - [Model.Filter](docs/Filter.md)
 - [Model.FirstName](docs/FirstName.md)
 - [Model.Folder](docs/Folder.md)
 - [Model.FolderItem](docs/FolderItem.md)
 - [Model.FolderItemResponse](docs/FolderItemResponse.md)
 - [Model.FolderItemV2](docs/FolderItemV2.md)
 - [Model.FolderItemsResponse](docs/FolderItemsResponse.md)
 - [Model.FoldersRequest](docs/FoldersRequest.md)
 - [Model.FoldersResponse](docs/FoldersResponse.md)
 - [Model.ForgottenPasswordInformation](docs/ForgottenPasswordInformation.md)
 - [Model.FormulaTab](docs/FormulaTab.md)
 - [Model.FullName](docs/FullName.md)
 - [Model.Group](docs/Group.md)
 - [Model.GroupInformation](docs/GroupInformation.md)
 - [Model.IdCheckInformationInput](docs/IdCheckInformationInput.md)
 - [Model.InPersonSigner](docs/InPersonSigner.md)
 - [Model.InitialHere](docs/InitialHere.md)
 - [Model.InlineTemplate](docs/InlineTemplate.md)
 - [Model.IntegratedUserInfoList](docs/IntegratedUserInfoList.md)
 - [Model.Intermediary](docs/Intermediary.md)
 - [Model.Jurisdiction](docs/Jurisdiction.md)
 - [Model.LastName](docs/LastName.md)
 - [Model.List](docs/List.md)
 - [Model.ListCustomField](docs/ListCustomField.md)
 - [Model.ListItem](docs/ListItem.md)
 - [Model.LockInformation](docs/LockInformation.md)
 - [Model.LockRequest](docs/LockRequest.md)
 - [Model.LoginAccount](docs/LoginAccount.md)
 - [Model.LoginInformation](docs/LoginInformation.md)
 - [Model.MatchBox](docs/MatchBox.md)
 - [Model.MemberGroupSharedItem](docs/MemberGroupSharedItem.md)
 - [Model.MemberSharedItems](docs/MemberSharedItems.md)
 - [Model.MergeField](docs/MergeField.md)
 - [Model.MobileNotifierConfiguration](docs/MobileNotifierConfiguration.md)
 - [Model.MobileNotifierConfigurationInformation](docs/MobileNotifierConfigurationInformation.md)
 - [Model.Money](docs/Money.md)
 - [Model.NameValue](docs/NameValue.md)
 - [Model.NewAccountDefinition](docs/NewAccountDefinition.md)
 - [Model.NewAccountSummary](docs/NewAccountSummary.md)
 - [Model.NewUser](docs/NewUser.md)
 - [Model.NewUsersDefinition](docs/NewUsersDefinition.md)
 - [Model.NewUsersSummary](docs/NewUsersSummary.md)
 - [Model.NotaryHost](docs/NotaryHost.md)
 - [Model.NotaryJournal](docs/NotaryJournal.md)
 - [Model.NotaryJournalCredibleWitness](docs/NotaryJournalCredibleWitness.md)
 - [Model.NotaryJournalList](docs/NotaryJournalList.md)
 - [Model.NotaryJournalMetaData](docs/NotaryJournalMetaData.md)
 - [Model.Note](docs/Note.md)
 - [Model.Notification](docs/Notification.md)
 - [Model.Number](docs/Number.md)
 - [Model.OauthAccess](docs/OauthAccess.md)
 - [Model.OfflineAttributes](docs/OfflineAttributes.md)
 - [Model.Page](docs/Page.md)
 - [Model.PageImages](docs/PageImages.md)
 - [Model.PageRequest](docs/PageRequest.md)
 - [Model.PaymentDetails](docs/PaymentDetails.md)
 - [Model.PaymentGatewayAccount](docs/PaymentGatewayAccount.md)
 - [Model.PaymentGatewayAccountsInfo](docs/PaymentGatewayAccountsInfo.md)
 - [Model.PaymentLineItem](docs/PaymentLineItem.md)
 - [Model.PaymentProcessorInformation](docs/PaymentProcessorInformation.md)
 - [Model.PermissionProfile](docs/PermissionProfile.md)
 - [Model.PermissionProfileInformation](docs/PermissionProfileInformation.md)
 - [Model.PlanInformation](docs/PlanInformation.md)
 - [Model.PostTransactionsRequest](docs/PostTransactionsRequest.md)
 - [Model.PostTransactionsResponse](docs/PostTransactionsResponse.md)
 - [Model.PowerForm](docs/PowerForm.md)
 - [Model.PowerFormFormDataEnvelope](docs/PowerFormFormDataEnvelope.md)
 - [Model.PowerFormFormDataRecipient](docs/PowerFormFormDataRecipient.md)
 - [Model.PowerFormRecipient](docs/PowerFormRecipient.md)
 - [Model.PowerFormSendersResponse](docs/PowerFormSendersResponse.md)
 - [Model.PowerFormsFormDataResponse](docs/PowerFormsFormDataResponse.md)
 - [Model.PowerFormsRequest](docs/PowerFormsRequest.md)
 - [Model.PowerFormsResponse](docs/PowerFormsResponse.md)
 - [Model.PropertyMetadata](docs/PropertyMetadata.md)
 - [Model.Province](docs/Province.md)
 - [Model.ProvisioningInformation](docs/ProvisioningInformation.md)
 - [Model.PurchasedEnvelopesInformation](docs/PurchasedEnvelopesInformation.md)
 - [Model.Radio](docs/Radio.md)
 - [Model.RadioGroup](docs/RadioGroup.md)
 - [Model.RecipientAttachment](docs/RecipientAttachment.md)
 - [Model.RecipientDomain](docs/RecipientDomain.md)
 - [Model.RecipientEmailNotification](docs/RecipientEmailNotification.md)
 - [Model.RecipientEvent](docs/RecipientEvent.md)
 - [Model.RecipientFormData](docs/RecipientFormData.md)
 - [Model.RecipientNamesResponse](docs/RecipientNamesResponse.md)
 - [Model.RecipientPhoneAuthentication](docs/RecipientPhoneAuthentication.md)
 - [Model.RecipientSAMLAuthentication](docs/RecipientSAMLAuthentication.md)
 - [Model.RecipientSMSAuthentication](docs/RecipientSMSAuthentication.md)
 - [Model.RecipientSignatureInformation](docs/RecipientSignatureInformation.md)
 - [Model.RecipientSignatureProvider](docs/RecipientSignatureProvider.md)
 - [Model.RecipientSignatureProviderOptions](docs/RecipientSignatureProviderOptions.md)
 - [Model.RecipientUpdateResponse](docs/RecipientUpdateResponse.md)
 - [Model.RecipientViewRequest](docs/RecipientViewRequest.md)
 - [Model.Recipients](docs/Recipients.md)
 - [Model.RecipientsUpdateSummary](docs/RecipientsUpdateSummary.md)
 - [Model.ReferralInformation](docs/ReferralInformation.md)
 - [Model.Reminders](docs/Reminders.md)
 - [Model.ResourceInformation](docs/ResourceInformation.md)
 - [Model.ReturnUrlRequest](docs/ReturnUrlRequest.md)
 - [Model.Revision](docs/Revision.md)
 - [Model.SamlAssertionAttribute](docs/SamlAssertionAttribute.md)
 - [Model.Seal](docs/Seal.md)
 - [Model.SealSign](docs/SealSign.md)
 - [Model.SeatDiscount](docs/SeatDiscount.md)
 - [Model.Sender](docs/Sender.md)
 - [Model.SenderEmailNotifications](docs/SenderEmailNotifications.md)
 - [Model.ServerTemplate](docs/ServerTemplate.md)
 - [Model.ServiceInformation](docs/ServiceInformation.md)
 - [Model.ServiceVersion](docs/ServiceVersion.md)
 - [Model.SettingsMetadata](docs/SettingsMetadata.md)
 - [Model.SharedItem](docs/SharedItem.md)
 - [Model.SignHashDocument](docs/SignHashDocument.md)
 - [Model.SignHashSessionInfoResponse](docs/SignHashSessionInfoResponse.md)
 - [Model.SignHere](docs/SignHere.md)
 - [Model.SignSessionInfoRequest](docs/SignSessionInfoRequest.md)
 - [Model.SignatureDataInfo](docs/SignatureDataInfo.md)
 - [Model.SignatureProviderRequiredOption](docs/SignatureProviderRequiredOption.md)
 - [Model.SignatureType](docs/SignatureType.md)
 - [Model.Signer](docs/Signer.md)
 - [Model.SignerAttachment](docs/SignerAttachment.md)
 - [Model.SignerEmailNotifications](docs/SignerEmailNotifications.md)
 - [Model.SigningGroup](docs/SigningGroup.md)
 - [Model.SigningGroupInformation](docs/SigningGroupInformation.md)
 - [Model.SigningGroupUser](docs/SigningGroupUser.md)
 - [Model.SigningGroupUsers](docs/SigningGroupUsers.md)
 - [Model.SocialAccountInformation](docs/SocialAccountInformation.md)
 - [Model.SocialAuthentication](docs/SocialAuthentication.md)
 - [Model.Ssn](docs/Ssn.md)
 - [Model.Ssn4InformationInput](docs/Ssn4InformationInput.md)
 - [Model.Ssn9InformationInput](docs/Ssn9InformationInput.md)
 - [Model.SupportedLanguages](docs/SupportedLanguages.md)
 - [Model.TabAccountSettings](docs/TabAccountSettings.md)
 - [Model.TabMetadata](docs/TabMetadata.md)
 - [Model.TabMetadataList](docs/TabMetadataList.md)
 - [Model.Tabs](docs/Tabs.md)
 - [Model.TemplateCustomFields](docs/TemplateCustomFields.md)
 - [Model.TemplateDocumentVisibilityList](docs/TemplateDocumentVisibilityList.md)
 - [Model.TemplateDocumentsResult](docs/TemplateDocumentsResult.md)
 - [Model.TemplateInformation](docs/TemplateInformation.md)
 - [Model.TemplateMatch](docs/TemplateMatch.md)
 - [Model.TemplateNotificationRequest](docs/TemplateNotificationRequest.md)
 - [Model.TemplateRecipients](docs/TemplateRecipients.md)
 - [Model.TemplateRole](docs/TemplateRole.md)
 - [Model.TemplateSharedItem](docs/TemplateSharedItem.md)
 - [Model.TemplateSummary](docs/TemplateSummary.md)
 - [Model.TemplateTabs](docs/TemplateTabs.md)
 - [Model.TemplateUpdateSummary](docs/TemplateUpdateSummary.md)
 - [Model.Text](docs/Text.md)
 - [Model.TextCustomField](docs/TextCustomField.md)
 - [Model.TimeStampField](docs/TimeStampField.md)
 - [Model.Title](docs/Title.md)
 - [Model.TspHealthCheckRequest](docs/TspHealthCheckRequest.md)
 - [Model.TspHealthCheckStatusDescription](docs/TspHealthCheckStatusDescription.md)
 - [Model.UpdateTransactionRequest](docs/UpdateTransactionRequest.md)
 - [Model.UpdateTransactionResponse](docs/UpdateTransactionResponse.md)
 - [Model.UsageHistory](docs/UsageHistory.md)
 - [Model.User](docs/User.md)
 - [Model.UserAccountManagementGranularInformation](docs/UserAccountManagementGranularInformation.md)
 - [Model.UserInfo](docs/UserInfo.md)
 - [Model.UserInfoList](docs/UserInfoList.md)
 - [Model.UserInfoResponse](docs/UserInfoResponse.md)
 - [Model.UserInformation](docs/UserInformation.md)
 - [Model.UserInformationList](docs/UserInformationList.md)
 - [Model.UserPasswordInformation](docs/UserPasswordInformation.md)
 - [Model.UserPasswordRules](docs/UserPasswordRules.md)
 - [Model.UserProfile](docs/UserProfile.md)
 - [Model.UserSettingsInformation](docs/UserSettingsInformation.md)
 - [Model.UserSharedItem](docs/UserSharedItem.md)
 - [Model.UserSignature](docs/UserSignature.md)
 - [Model.UserSignatureDefinition](docs/UserSignatureDefinition.md)
 - [Model.UserSignaturesInformation](docs/UserSignaturesInformation.md)
 - [Model.UserSocialIdResult](docs/UserSocialIdResult.md)
 - [Model.UsersResponse](docs/UsersResponse.md)
 - [Model.View](docs/View.md)
 - [Model.ViewLinkRequest](docs/ViewLinkRequest.md)
 - [Model.ViewUrl](docs/ViewUrl.md)
 - [Model.Watermark](docs/Watermark.md)
 - [Model.Workspace](docs/Workspace.md)
 - [Model.WorkspaceFolderContents](docs/WorkspaceFolderContents.md)
 - [Model.WorkspaceItem](docs/WorkspaceItem.md)
 - [Model.WorkspaceItemList](docs/WorkspaceItemList.md)
 - [Model.WorkspaceList](docs/WorkspaceList.md)
 - [Model.WorkspaceUser](docs/WorkspaceUser.md)
 - [Model.WorkspaceUserAuthorization](docs/WorkspaceUserAuthorization.md)
 - [Model.Zip](docs/Zip.md)


<a name="documentation-for-authorization"></a>
## Documentation for Authorization

<a name="docusignAccessCode"></a>
### docusignAccessCode

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: 
- **Scopes**: N/A

