# DocuSign.eSign.Api.ConnectApi

All URIs are relative to *https://www.docusign.net/restapi*

Method | HTTP request | Description
------------- | ------------- | -------------
[**CreateConfiguration**](ConnectApi.md#createconfiguration) | **POST** /v2/accounts/{accountId}/connect | Creates a connect configuration for the specified account.
[**DeleteConfiguration**](ConnectApi.md#deleteconfiguration) | **DELETE** /v2/accounts/{accountId}/connect/{connectId} | Deletes the specified connect configuration.
[**DeleteEventFailureLog**](ConnectApi.md#deleteeventfailurelog) | **DELETE** /v2/accounts/{accountId}/connect/failures/{failureId} | Deletes a Connect failure log entry.
[**DeleteEventLog**](ConnectApi.md#deleteeventlog) | **DELETE** /v2/accounts/{accountId}/connect/logs/{logId} | Deletes a specified Connect log entry.
[**DeleteEventLogs**](ConnectApi.md#deleteeventlogs) | **DELETE** /v2/accounts/{accountId}/connect/logs | Gets a list of Connect log entries.
[**DeleteMobileNotifiers**](ConnectApi.md#deletemobilenotifiers) | **DELETE** /v2/accounts/{accountId}/connect/mobile_notifiers | Reserved
[**GetConfiguration**](ConnectApi.md#getconfiguration) | **GET** /v2/accounts/{accountId}/connect/{connectId} | Get a Connect Configuration Information
[**GetEventLog**](ConnectApi.md#geteventlog) | **GET** /v2/accounts/{accountId}/connect/logs/{logId} | Get the specified Connect log entry.
[**ListConfigurations**](ConnectApi.md#listconfigurations) | **GET** /v2/accounts/{accountId}/connect | Get Connect Configuration Information
[**ListEventFailureLogs**](ConnectApi.md#listeventfailurelogs) | **GET** /v2/accounts/{accountId}/connect/failures | Gets the Connect failure log information.
[**ListEventLogs**](ConnectApi.md#listeventlogs) | **GET** /v2/accounts/{accountId}/connect/logs | Gets the Connect log.
[**ListMobileNotifiers**](ConnectApi.md#listmobilenotifiers) | **GET** /v2/accounts/{accountId}/connect/mobile_notifiers | Reserved
[**ListTests**](ConnectApi.md#listtests) | **GET** /v2/accounts/{accountId}/connect/{connectId}/tests | Test connect configuration.
[**ListUsers**](ConnectApi.md#listusers) | **GET** /v2/accounts/{accountId}/connect/{connectId}/users | Returns users from the configured Connect service.
[**RetryEventForEnvelope**](ConnectApi.md#retryeventforenvelope) | **PUT** /v2/accounts/{accountId}/connect/envelopes/{envelopeId}/retry_queue | Republishes Connect information for the specified envelope.
[**RetryEventForEnvelopes**](ConnectApi.md#retryeventforenvelopes) | **PUT** /v2/accounts/{accountId}/connect/envelopes/retry_queue | Republishes Connect information for multiple envelopes.
[**UpdateConfiguration**](ConnectApi.md#updateconfiguration) | **PUT** /v2/accounts/{accountId}/connect | Updates a specified Connect configuration.
[**UpdateMobileNotifiers**](ConnectApi.md#updatemobilenotifiers) | **PUT** /v2/accounts/{accountId}/connect/mobile_notifiers | Reserved


<a name="createconfiguration"></a>
# **CreateConfiguration**
> ConnectCustomConfiguration CreateConfiguration (ConnectCustomConfiguration connectCustomConfiguration = null, string accountId)

Creates a connect configuration for the specified account.

Creates a DocuSign Custom Connect definition for your account. DocuSign Connect enables the sending of real-time data updates to external applications. These updates are generated by user transactions as the envelope progresses through actions to completion. The Connect Service provides updated information about the status of these transactions and returns updates that include the actual content of document form fields. Be aware that, these updates might or might not include the document itself. For more information about Connect, see the [ML:DocuSign Connect Service Guide].  ###### Note: Connect must be enabled for your account to use this function. This cannot be used to set up Connect configurations for Salesforce or eOriginal.

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class CreateConfigurationExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var connectCustomConfiguration = new ConnectCustomConfiguration(); // ConnectCustomConfiguration |  (optional) 
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.

            try
            {
                // Creates a connect configuration for the specified account.
                ConnectCustomConfiguration result = apiInstance.CreateConfiguration(connectCustomConfiguration, accountId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.CreateConfiguration: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **connectCustomConfiguration** | [**ConnectCustomConfiguration**](ConnectCustomConfiguration.md)|  | [optional] 
 **accountId** | **string**| The external account number (int) or account ID Guid. | 

### Return type

[**ConnectCustomConfiguration**](ConnectCustomConfiguration.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="deleteconfiguration"></a>
# **DeleteConfiguration**
> void DeleteConfiguration (string accountId, string connectId)

Deletes the specified connect configuration.

Deletes the specified DocuSign Connect configuration.  ###### Note: Connect must be enabled for your account to use this function.    

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class DeleteConfigurationExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.
            var connectId = connectId_example;  // string | The ID of the custom Connect configuration being accessed.

            try
            {
                // Deletes the specified connect configuration.
                apiInstance.DeleteConfiguration(accountId, connectId);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.DeleteConfiguration: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **string**| The external account number (int) or account ID Guid. | 
 **connectId** | **string**| The ID of the custom Connect configuration being accessed. | 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="deleteeventfailurelog"></a>
# **DeleteEventFailureLog**
> void DeleteEventFailureLog (string accountId, string failureId)

Deletes a Connect failure log entry.

Deletes the Connect failure log information for the specified entry.

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class DeleteEventFailureLogExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.
            var failureId = failureId_example;  // string | The ID of the failed connect log entry.

            try
            {
                // Deletes a Connect failure log entry.
                apiInstance.DeleteEventFailureLog(accountId, failureId);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.DeleteEventFailureLog: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **string**| The external account number (int) or account ID Guid. | 
 **failureId** | **string**| The ID of the failed connect log entry. | 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="deleteeventlog"></a>
# **DeleteEventLog**
> void DeleteEventLog (string accountId, string logId)

Deletes a specified Connect log entry.

Deletes a specified entry from the Connect Log. 

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class DeleteEventLogExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.
            var logId = logId_example;  // string | The ID of the connect log entry

            try
            {
                // Deletes a specified Connect log entry.
                apiInstance.DeleteEventLog(accountId, logId);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.DeleteEventLog: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **string**| The external account number (int) or account ID Guid. | 
 **logId** | **string**| The ID of the connect log entry | 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="deleteeventlogs"></a>
# **DeleteEventLogs**
> void DeleteEventLogs (string accountId)

Gets a list of Connect log entries.

Retrieves a list of connect log entries for your account.  ###### Note: The `enableLog` property in the Connect configuration must be set to **true** to enable logging. If logging is not enabled, then no log entries are recorded.

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class DeleteEventLogsExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.

            try
            {
                // Gets a list of Connect log entries.
                apiInstance.DeleteEventLogs(accountId);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.DeleteEventLogs: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **string**| The external account number (int) or account ID Guid. | 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="deletemobilenotifiers"></a>
# **DeleteMobileNotifiers**
> MobileNotifierConfigurationInformation DeleteMobileNotifiers (MobileNotifierConfigurationInformation mobileNotifierConfigurationInformation = null, string accountId)

Reserved

Reserved:

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class DeleteMobileNotifiersExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var mobileNotifierConfigurationInformation = new MobileNotifierConfigurationInformation(); // MobileNotifierConfigurationInformation |  (optional) 
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.

            try
            {
                // Reserved
                MobileNotifierConfigurationInformation result = apiInstance.DeleteMobileNotifiers(mobileNotifierConfigurationInformation, accountId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.DeleteMobileNotifiers: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **mobileNotifierConfigurationInformation** | [**MobileNotifierConfigurationInformation**](MobileNotifierConfigurationInformation.md)|  | [optional] 
 **accountId** | **string**| The external account number (int) or account ID Guid. | 

### Return type

[**MobileNotifierConfigurationInformation**](MobileNotifierConfigurationInformation.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getconfiguration"></a>
# **GetConfiguration**
> ConnectConfigResults GetConfiguration (string accountId, string connectId)

Get a Connect Configuration Information

Retrieves the information for the specified DocuSign Connect configuration.  ###### Note: Connect must be enabled for your account to use this function. 

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class GetConfigurationExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.
            var connectId = connectId_example;  // string | The ID of the custom Connect configuration being accessed.

            try
            {
                // Get a Connect Configuration Information
                ConnectConfigResults result = apiInstance.GetConfiguration(accountId, connectId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.GetConfiguration: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **string**| The external account number (int) or account ID Guid. | 
 **connectId** | **string**| The ID of the custom Connect configuration being accessed. | 

### Return type

[**ConnectConfigResults**](ConnectConfigResults.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="geteventlog"></a>
# **GetEventLog**
> ConnectLog GetEventLog (string additionalInfo = null, string accountId, string logId)

Get the specified Connect log entry.

Retrieves the specified Connect log entry for your account.  ###### Note: The `enableLog` setting in the Connect configuration must be set to true to enable logging. If logging is not enabled, then no log entries are recorded. 

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class GetEventLogExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var additionalInfo = additionalInfo_example;  // string | When true, the connectDebugLog information is included in the response. (optional) 
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.
            var logId = logId_example;  // string | The ID of the connect log entry

            try
            {
                // Get the specified Connect log entry.
                ConnectLog result = apiInstance.GetEventLog(additionalInfo, accountId, logId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.GetEventLog: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **additionalInfo** | **string**| When true, the connectDebugLog information is included in the response. | [optional] 
 **accountId** | **string**| The external account number (int) or account ID Guid. | 
 **logId** | **string**| The ID of the connect log entry | 

### Return type

[**ConnectLog**](ConnectLog.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="listconfigurations"></a>
# **ListConfigurations**
> ConnectConfigResults ListConfigurations (string accountId)

Get Connect Configuration Information

Retrieves all the DocuSign Custom Connect definitions for the specified account.  ###### Note: Connect must be enabled for your account to use this function. This does not retrieve information for Connect configurations for Box, eOriginal, or Salesforce.

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class ListConfigurationsExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.

            try
            {
                // Get Connect Configuration Information
                ConnectConfigResults result = apiInstance.ListConfigurations(accountId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.ListConfigurations: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **string**| The external account number (int) or account ID Guid. | 

### Return type

[**ConnectConfigResults**](ConnectConfigResults.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="listeventfailurelogs"></a>
# **ListEventFailureLogs**
> ConnectLogs ListEventFailureLogs (string fromDate = null, string toDate = null, string accountId)

Gets the Connect failure log information.

Retrieves the Connect Failure Log information. It can be used to determine which envelopes failed to post, so a republish request can be created.

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class ListEventFailureLogsExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var fromDate = fromDate_example;  // string |  (optional) 
            var toDate = toDate_example;  // string |  (optional) 
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.

            try
            {
                // Gets the Connect failure log information.
                ConnectLogs result = apiInstance.ListEventFailureLogs(fromDate, toDate, accountId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.ListEventFailureLogs: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **fromDate** | **string**|  | [optional] 
 **toDate** | **string**|  | [optional] 
 **accountId** | **string**| The external account number (int) or account ID Guid. | 

### Return type

[**ConnectLogs**](ConnectLogs.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="listeventlogs"></a>
# **ListEventLogs**
> ConnectLogs ListEventLogs (string fromDate = null, string toDate = null, string accountId)

Gets the Connect log.

Retrieves a list of connect log entries for your account.  ###### Note: The `enableLog` setting in the Connect configuration must be set to true to enable logging. If logging is not enabled, then no log entries are recorded. 

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class ListEventLogsExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var fromDate = fromDate_example;  // string |  (optional) 
            var toDate = toDate_example;  // string |  (optional) 
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.

            try
            {
                // Gets the Connect log.
                ConnectLogs result = apiInstance.ListEventLogs(fromDate, toDate, accountId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.ListEventLogs: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **fromDate** | **string**|  | [optional] 
 **toDate** | **string**|  | [optional] 
 **accountId** | **string**| The external account number (int) or account ID Guid. | 

### Return type

[**ConnectLogs**](ConnectLogs.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="listmobilenotifiers"></a>
# **ListMobileNotifiers**
> MobileNotifierConfigurationInformation ListMobileNotifiers (string accountId)

Reserved

Reserved:

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class ListMobileNotifiersExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.

            try
            {
                // Reserved
                MobileNotifierConfigurationInformation result = apiInstance.ListMobileNotifiers(accountId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.ListMobileNotifiers: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **string**| The external account number (int) or account ID Guid. | 

### Return type

[**MobileNotifierConfigurationInformation**](MobileNotifierConfigurationInformation.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="listtests"></a>
# **ListTests**
> ResourceInformation ListTests (string accountId, string connectId)

Test connect configuration.

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class ListTestsExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.
            var connectId = connectId_example;  // string | The ID of the custom Connect configuration being accessed.

            try
            {
                // Test connect configuration.
                ResourceInformation result = apiInstance.ListTests(accountId, connectId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.ListTests: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **string**| The external account number (int) or account ID Guid. | 
 **connectId** | **string**| The ID of the custom Connect configuration being accessed. | 

### Return type

[**ResourceInformation**](ResourceInformation.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="listusers"></a>
# **ListUsers**
> IntegratedUserInfoList ListUsers (string count = null, string emailSubstring = null, string listIncludedUsers = null, string startPosition = null, string status = null, string userNameSubstring = null, string accountId, string connectId)

Returns users from the configured Connect service.

Returns users from the configured Connect service.

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class ListUsersExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var count = count_example;  // string |  (optional) 
            var emailSubstring = emailSubstring_example;  // string |  (optional) 
            var listIncludedUsers = listIncludedUsers_example;  // string |  (optional) 
            var startPosition = startPosition_example;  // string |  (optional) 
            var status = status_example;  // string |  (optional) 
            var userNameSubstring = userNameSubstring_example;  // string |  (optional) 
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.
            var connectId = connectId_example;  // string | The ID of the custom Connect configuration being accessed.

            try
            {
                // Returns users from the configured Connect service.
                IntegratedUserInfoList result = apiInstance.ListUsers(count, emailSubstring, listIncludedUsers, startPosition, status, userNameSubstring, accountId, connectId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.ListUsers: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **count** | **string**|  | [optional] 
 **emailSubstring** | **string**|  | [optional] 
 **listIncludedUsers** | **string**|  | [optional] 
 **startPosition** | **string**|  | [optional] 
 **status** | **string**|  | [optional] 
 **userNameSubstring** | **string**|  | [optional] 
 **accountId** | **string**| The external account number (int) or account ID Guid. | 
 **connectId** | **string**| The ID of the custom Connect configuration being accessed. | 

### Return type

[**IntegratedUserInfoList**](IntegratedUserInfoList.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="retryeventforenvelope"></a>
# **RetryEventForEnvelope**
> ConnectFailureResults RetryEventForEnvelope (string accountId, string envelopeId)

Republishes Connect information for the specified envelope.

Republishes Connect information for the specified envelope.

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class RetryEventForEnvelopeExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.
            var envelopeId = envelopeId_example;  // string | The envelopeId Guid of the envelope being accessed.

            try
            {
                // Republishes Connect information for the specified envelope.
                ConnectFailureResults result = apiInstance.RetryEventForEnvelope(accountId, envelopeId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.RetryEventForEnvelope: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **string**| The external account number (int) or account ID Guid. | 
 **envelopeId** | **string**| The envelopeId Guid of the envelope being accessed. | 

### Return type

[**ConnectFailureResults**](ConnectFailureResults.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="retryeventforenvelopes"></a>
# **RetryEventForEnvelopes**
> ConnectFailureResults RetryEventForEnvelopes (ConnectFailureFilter connectFailureFilter = null, string accountId)

Republishes Connect information for multiple envelopes.

Republishes Connect information for the  specified set of envelopes. The primary use is to republish Connect post failures by including envelope IDs for the envelopes that failed to post in the request. The list of envelope IDs that failed to post correctly can be retrieved by calling to [ML:GetConnectLog] retrieve the failure log.

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class RetryEventForEnvelopesExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var connectFailureFilter = new ConnectFailureFilter(); // ConnectFailureFilter |  (optional) 
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.

            try
            {
                // Republishes Connect information for multiple envelopes.
                ConnectFailureResults result = apiInstance.RetryEventForEnvelopes(connectFailureFilter, accountId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.RetryEventForEnvelopes: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **connectFailureFilter** | [**ConnectFailureFilter**](ConnectFailureFilter.md)|  | [optional] 
 **accountId** | **string**| The external account number (int) or account ID Guid. | 

### Return type

[**ConnectFailureResults**](ConnectFailureResults.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="updateconfiguration"></a>
# **UpdateConfiguration**
> ConnectCustomConfiguration UpdateConfiguration (ConnectCustomConfiguration connectCustomConfiguration = null, string accountId)

Updates a specified Connect configuration.

Updates the specified DocuSign Connect configuration in your account.  ###### Note: Connect must be enabled for your account to use this function. This cannot be used to update Connect configurations for Box, eOriginal, or Salesforce.

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class UpdateConfigurationExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var connectCustomConfiguration = new ConnectCustomConfiguration(); // ConnectCustomConfiguration |  (optional) 
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.

            try
            {
                // Updates a specified Connect configuration.
                ConnectCustomConfiguration result = apiInstance.UpdateConfiguration(connectCustomConfiguration, accountId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.UpdateConfiguration: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **connectCustomConfiguration** | [**ConnectCustomConfiguration**](ConnectCustomConfiguration.md)|  | [optional] 
 **accountId** | **string**| The external account number (int) or account ID Guid. | 

### Return type

[**ConnectCustomConfiguration**](ConnectCustomConfiguration.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="updatemobilenotifiers"></a>
# **UpdateMobileNotifiers**
> MobileNotifierConfigurationInformation UpdateMobileNotifiers (MobileNotifierConfigurationInformation mobileNotifierConfigurationInformation = null, string accountId)

Reserved

Reserved:

### Example
```csharp
using System;
using System.Diagnostics;
using DocuSign.eSign.Api;
using DocuSign.eSign.Client;
using DocuSign.eSign.Model;

namespace Example
{
    public class UpdateMobileNotifiersExample
    {
        public void main()
        {
            
            var apiInstance = new ConnectApi();
            var mobileNotifierConfigurationInformation = new MobileNotifierConfigurationInformation(); // MobileNotifierConfigurationInformation |  (optional) 
            var accountId = accountId_example;  // string | The external account number (int) or account ID Guid.

            try
            {
                // Reserved
                MobileNotifierConfigurationInformation result = apiInstance.UpdateMobileNotifiers(mobileNotifierConfigurationInformation, accountId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ConnectApi.UpdateMobileNotifiers: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **mobileNotifierConfigurationInformation** | [**MobileNotifierConfigurationInformation**](MobileNotifierConfigurationInformation.md)|  | [optional] 
 **accountId** | **string**| The external account number (int) or account ID Guid. | 

### Return type

[**MobileNotifierConfigurationInformation**](MobileNotifierConfigurationInformation.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

